@@ -4,14 +4,14 @@
 <context>
     <name>CreateBlock</name>
     <message>
-        <location filename="../CreateBlock.js" line="+53"/>
+        <location filename="../CreateBlock.js" line="+51"/>
         <source>Reference Point</source>
         <translation>Referenční bod</translation>
     </message>
     <message>
         <location filename="../CreateBlockInit.js" line="+2"/>
         <source>&amp;Create Block from Selection</source>
-        <translation>&amp;Vytvořit blok dle výběru</translation>
+        <translation>&amp;Vytvořit blok z výběru</translation>
     </message>
 </context>
 </TS>
