@@ -1,10 +1,10 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="fr_FR">
+<TS version="2.1" language="fr">
 <context>
     <name>CreateBlock</name>
     <message>
-        <location filename="../CreateBlock.js" line="+53"/>
+        <location filename="../CreateBlock.js" line="+51"/>
         <source>Reference Point</source>
         <translation>Point de référence</translation>
     </message>
@@ -19,7 +19,7 @@
     <message>
         <location filename="../CreateBlockInit.js" line="+2"/>
         <source>&amp;Create Block from Selection</source>
-        <translation>&amp;Créer un bloc de la sélection</translation>
+        <translation>&amp;Créer un bloc à partir de la sélection</translation>
     </message>
 </context>
 </TS>
