@@ -21,7 +21,7 @@
     <message>
         <location line="+1"/>
         <source>Create library item from selection</source>
-        <translation>Vytvořit položku knihovny dle výběru</translation>
+        <translation>Vytvořit položku knihovny z výběru</translation>
     </message>
 </context>
 </TS>
