@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>HideAllBlocks</name>
     <message>
@@ -14,7 +14,7 @@
     <message>
         <location filename="../HideAllBlocksInit.js" line="+2"/>
         <source>&amp;Hide All Blocks</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Ukryj wszystkie bloki</translation>
     </message>
 </context>
 </TS>
