@@ -3,11 +3,6 @@
 <TS version="2.1" language="zh_TW">
 <context>
     <name>InsertScriptItem</name>
-    <message>
-        <location filename="../InsertScriptItem.js" line="+71"/>
-        <source>Position</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../InsertScriptItemInit.js" line="+2"/>
         <source>Insert &amp;Script</source>
