@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>ToggleBlockVisibility</name>
     <message>
@@ -9,7 +9,7 @@
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 &amp;Zmień widoczność</translatorcomment>
-        <translation type="unfinished">&amp;Zmień widoczność</translation>
+        <translation>&amp;Przełącz widoczność</translation>
     </message>
 </context>
 </TS>
