@@ -6,17 +6,17 @@
     <message>
         <location filename="../ArcConcentricThrough.ui" line="+17"/>
         <source>Number:</source>
-        <translation>数字：</translation>
+        <translation>数量：</translation>
     </message>
     <message>
         <location filename="../ArcConcentricThroughInit.js" line="+2"/>
         <source>Concentric (&amp;through Point)</source>
-        <translation>同心的点(&amp;t)</translation>
+        <translation>同心弧（以弧外点）(&amp;t)</translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Draw concentric arc through point</source>
-        <translation>根据点画同心弧</translation>
+        <translation>以弧外一点画同心弧</translation>
     </message>
 </context>
 </TS>
