@@ -4,7 +4,7 @@
 <context>
     <name>Circle2TR</name>
     <message>
-        <location filename="../Circle2TR.js" line="+76"/>
+        <location filename="../Circle2TR.js" line="+77"/>
         <source>First line, arc or circle</source>
         <translation type="unfinished"></translation>
     </message>
@@ -19,16 +19,10 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+97"/>
-        <location line="+94"/>
+        <location line="+99"/>
         <source>No solution</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location line="-44"/>
-        <source>Invalid radius</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../Circle2TR.ui" line="+17"/>
         <source>Radius:</source>
