@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>Circle3P</name>
     <message>
@@ -10,7 +10,7 @@
 Wskaż pierwszy punkt
 Wskaż pierwszy punkt wieloboku
 Wskaż pierwszy punkt odległości</translatorcomment>
-        <translation type="unfinished">Pierwszy punkt</translation>
+        <translation>Pierwszy punkt</translation>
     </message>
     <message>
         <location line="+9"/>
@@ -19,14 +19,14 @@ Wskaż pierwszy punkt odległości</translatorcomment>
 Wskaż drugi punkt
 Wskaż dugi punkt odległości
 Wskaż drugi punkt linii odbicia</translatorcomment>
-        <translation type="unfinished">Drugi punkt</translation>
+        <translation>Drugi punkt</translation>
     </message>
     <message>
         <location line="+8"/>
         <source>Third point</source>
         <translatorcomment>--google--
 Wskaż trzeci punkt</translatorcomment>
-        <translation type="unfinished">Trzeci punkt</translation>
+        <translation>Trzeci punkt</translation>
     </message>
     <message>
         <location filename="../Circle3PInit.js" line="+2"/>
@@ -34,13 +34,13 @@ Wskaż trzeci punkt</translatorcomment>
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 &amp;3 Punkty</translatorcomment>
-        <translation type="unfinished">&amp;3 Punkty</translation>
+        <translation>&amp;3 punkty</translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Draw circle from 3 points</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Narysuj koło z 3 punktów</translation>
+        <translation>Rysuje okrąg przez 3 punkty</translation>
     </message>
 </context>
 </TS>
