@@ -1,43 +1,43 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>Circle3T</name>
     <message>
         <location filename="../Circle3T.js" line="+84"/>
         <source>First line, arc or circle</source>
-        <translation type="unfinished"></translation>
+        <translation>Pierwsza linia, łuk lub okrąg</translation>
     </message>
     <message>
         <location line="+14"/>
         <source>Second line, arc or circle</source>
-        <translation type="unfinished"></translation>
+        <translation>Druga linia, łuk lub okrąg</translation>
     </message>
     <message>
         <location line="+12"/>
         <source>Third line, arc or circle</source>
-        <translation type="unfinished"></translation>
+        <translation>Trzecia linia, łuk lub okrąg</translation>
     </message>
     <message>
         <location line="+8"/>
         <source>Choose solution</source>
-        <translation type="unfinished"></translation>
+        <translation>Proszę wskazać rozwiązanie</translation>
     </message>
     <message>
-        <location line="+115"/>
-        <location line="+60"/>
+        <location line="+116"/>
+        <location line="+61"/>
         <source>No solution</source>
-        <translation type="unfinished"></translation>
+        <translation>Brak rozwiązania</translation>
     </message>
     <message>
         <location filename="../Circle3TInit.js" line="+2"/>
         <source>3 T&amp;angents</source>
-        <translation type="unfinished"></translation>
+        <translation>3 sty&amp;czne</translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Draw circle tangential to three entities</source>
-        <translation type="unfinished"></translation>
+        <translation>Rysuje okrąg styczny do trzech elementów</translation>
     </message>
 </context>
 </TS>
