@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>CircleCP</name>
     <message>
@@ -10,26 +10,26 @@
 --file: qt_pl.ts--
 Wskaż środek
 Łuk: środek, punkt, kąty</translatorcomment>
-        <translation type="unfinished">Wyśrodkuj</translation>
+        <translation>Środek</translation>
     </message>
     <message>
         <location line="+7"/>
         <source>Point on circle or radius</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Punkt na okręgu lub promień</translation>
+        <translation>Punkt na okręgu lub promień</translation>
     </message>
     <message>
         <location filename="../CircleCPInit.js" line="+2"/>
         <source>&amp;Center, Point</source>
         <translatorcomment>--google--
 ś&amp;rodek, punkt, kąty</translatorcomment>
-        <translation type="unfinished">Center, Point</translation>
+        <translation>Ś&amp;rodek, punkt</translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Draw circle from center and point on circle</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Narysuj koło od centrum i punkt na okręgu</translation>
+        <translation>Rysuje okrąg od środka, przez punkt na okręgu</translation>
     </message>
 </context>
 </TS>
