@@ -1,28 +1,28 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>DimAngular</name>
     <message>
-        <location filename="../DimAngular.js" line="+72"/>
+        <location filename="../DimAngular.js" line="+80"/>
         <source>Arc or first of two lines</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Arc lub pierwszy z dwóch linii</translation>
+        <translation>Łuk lub pierwsza z dwóch linii</translation>
     </message>
     <message>
-        <location line="+12"/>
+        <location line="+13"/>
         <source>Second line</source>
         <translatorcomment>--google--
 Zaznacz drugą linię
 Wskaż drugą linię [długość/liczba]
 Wskaż drugą linie</translatorcomment>
-        <translation type="unfinished">Druga linia</translation>
+        <translation>Druga linia</translation>
     </message>
     <message>
         <location line="+8"/>
         <source>Dimension arc location</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Lokalizacja arc wymiar</translation>
+        <translation>Położenie wymiaru łuku</translation>
     </message>
     <message>
         <location filename="../DimAngularInit.js" line="+2"/>
@@ -30,13 +30,13 @@ Wskaż drugą linie</translatorcomment>
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 &amp;Kątowy</translatorcomment>
-        <translation type="unfinished">&amp;Kątowy</translation>
+        <translation>&amp;Kątowy</translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Draw angular dimension</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Narysuj wymiar kątowy</translation>
+        <translation>Rysuje wymiar kątowy</translation>
     </message>
 </context>
 </TS>
