@@ -1,19 +1,19 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>DimDiametric</name>
     <message>
         <location filename="../DimDiametric.js" line="+57"/>
         <source>Choose arc or circle entity</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Wybierz łuk lub okrąg encji</translation>
+        <translation>Proszę wskazać  łuk lub okrąg</translation>
     </message>
     <message>
         <location line="+8"/>
         <source>Dimension line location or angle</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Położenie linii wymiarowej lub kąt</translation>
+        <translation>Położenie lub kąt linii wymiarowej</translation>
     </message>
     <message>
         <location filename="../DimDiametricInit.js" line="+2"/>
@@ -21,13 +21,13 @@
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 Śre&amp;dnicowy</translatorcomment>
-        <translation type="unfinished">Śre&amp;dnicowy</translation>
+        <translation>Śre&amp;dnicowy</translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Draw diametric dimension</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Remis diametric wymiar</translation>
+        <translation>Rysuje wymiar średnicowy</translation>
     </message>
 </context>
 </TS>
