@@ -8,10 +8,17 @@
         <source>No dimension entities with custom label positions selected.</source>
         <translation>Ei ole valittu mittatietoja mukautetun selitteen sijainnille.</translation>
     </message>
-    <message>
+    <message numerus="yes">
         <location line="+3"/>
+        <source>Label position of %n dimension(s) was reset.</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
         <source>Reset label position of %1 dimension(s).</source>
-        <translation>Nollaa selitteen sijainti %1 mittasuhteesta(-suhteista).</translation>
+        <translation type="vanished">Nollaa selitteen sijainti %1 mittasuhteesta(-suhteista).</translation>
     </message>
     <message>
         <location filename="../DimRegenInit.js" line="+2"/>
