@@ -8,10 +8,17 @@
         <source>No dimension entities with custom label positions selected.</source>
         <translation>Aucun objets de dimension sélectionné avec une position de texte personnalisé.</translation>
     </message>
-    <message>
+    <message numerus="yes">
         <location line="+3"/>
+        <source>Label position of %n dimension(s) was reset.</source>
+        <translation>
+            <numerusform>Position de l&apos;étiquette d&apos;un dimension a été réinitialisé.</numerusform>
+            <numerusform>Position de l&apos;étiquette de %n dimensions a été réinitialisé.</numerusform>
+        </translation>
+    </message>
+    <message>
         <source>Reset label position of %1 dimension(s).</source>
-        <translation>Position de l&apos;étiquette de %1 dimension(s) a été réinitialisé.</translation>
+        <translation type="vanished">Position de l&apos;étiquette de %1 dimension(s) a été réinitialisé.</translation>
     </message>
     <message>
         <location filename="../DimRegenInit.js" line="+2"/>
