@@ -8,10 +8,12 @@
         <source>No dimension entities with custom label positions selected.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
+    <message numerus="yes">
         <location line="+3"/>
-        <source>Reset label position of %1 dimension(s).</source>
-        <translation type="unfinished"></translation>
+        <source>Label position of %n dimension(s) was reset.</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
     </message>
     <message>
         <location filename="../DimRegenInit.js" line="+2"/>
