@@ -8,10 +8,17 @@
         <source>No dimension entities with custom label positions selected.</source>
         <translation>Nessun quote selezionata con una posizione di testo personalizzato.</translation>
     </message>
-    <message>
+    <message numerus="yes">
         <location line="+3"/>
+        <source>Label position of %n dimension(s) was reset.</source>
+        <translation>
+            <numerusform>Posizione dell&apos;etichetta di %1 dimensione è stato azzerato.</numerusform>
+            <numerusform>Posizione dell&apos;etichetta di %1 dimensiones è stato azzerato.</numerusform>
+        </translation>
+    </message>
+    <message>
         <source>Reset label position of %1 dimension(s).</source>
-        <translation>Posizione dell&apos;etichetta di %1 dimensione(s) è stato azzerato.</translation>
+        <translation type="vanished">Posizione dell&apos;etichetta di %1 dimensione(s) è stato azzerato.</translation>
     </message>
     <message>
         <location filename="../DimRegenInit.js" line="+2"/>
