@@ -8,10 +8,18 @@
         <source>No dimension entities with custom label positions selected.</source>
         <translation>Žiadna kóta s vlastným nastavením pozície textu.</translation>
     </message>
-    <message>
+    <message numerus="yes">
         <location line="+3"/>
+        <source>Label position of %n dimension(s) was reset.</source>
+        <translation>
+            <numerusform>Pozícia textu %n kóty(kót) bola resetovaná.</numerusform>
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
         <source>Reset label position of %1 dimension(s).</source>
-        <translation>Vynulovalo pozíciu textu na %1 kótach (kóte).</translation>
+        <translation type="vanished">Vynulovalo pozíciu textu na %1 kótach (kóte).</translation>
     </message>
     <message>
         <location filename="../DimRegenInit.js" line="+2"/>
