@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>EllipseCPP</name>
     <message>
@@ -11,13 +11,13 @@
     <message>
         <location filename="../EllipseCPPInit.js" line="+2"/>
         <source>&amp;Ellipse (Center, Point, Ratio)</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Elipsa (środek, punkt, proporcja)</translation>
     </message>
     <message>
         <location line="+4"/>
         <source>Draw full ellipse from center, major point and ratio</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Remis pełną elipsę od centrum, punkt główny i współczynnika</translation>
+        <translation>Rysuje pełną elipsę od środka, przez punkt i o danej proporcji</translation>
     </message>
 </context>
 </TS>
