@@ -9,12 +9,12 @@
     </message>
     <message>
         <source>&amp;Full Ellipse with Center, Point, Ratio</source>
-        <translation type="vanished">&amp;Polna elipsa z središčem, točko, razmerje</translation>
+        <translation type="vanished">&amp;Polna elipsa s središčem, točko, razmerjem</translation>
     </message>
     <message>
         <location filename="../EllipseCPPInit.js" line="+2"/>
         <source>&amp;Ellipse (Center, Point, Ratio)</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Elipsa (Središče, Točka, Razmerje)</translation>
     </message>
     <message>
         <location line="+4"/>
