@@ -1,40 +1,40 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>EllipseDD</name>
     <message>
         <location filename="../EllipseDD.ui" line="+17"/>
         <location filename="../EllipseDDDialog.ui" line="+19"/>
         <source>X Diameter:</source>
-        <translation type="unfinished"></translation>
+        <translation>Średnica X:</translation>
     </message>
     <message>
         <location line="+23"/>
         <location filename="../EllipseDDDialog.ui" line="+80"/>
         <source>Y Diameter:</source>
-        <translation type="unfinished"></translation>
+        <translation>Średnica Y:</translation>
     </message>
     <message>
         <location line="+30"/>
         <location filename="../EllipseDDDialog.ui" line="-23"/>
         <source>Angle:</source>
-        <translation type="unfinished"></translation>
+        <translation>Kąt:</translation>
     </message>
     <message>
         <location line="+36"/>
         <source>Reference Point:</source>
-        <translation type="unfinished"></translation>
+        <translation>Punkt odniesienia:</translation>
     </message>
     <message>
         <location filename="../EllipseDDInit.js" line="+2"/>
         <source>Ellipse with &amp;Diameters</source>
-        <translation type="unfinished"></translation>
+        <translation>Elipsa o śr&amp;ednicach</translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Draw ellipse with position and diameters</source>
-        <translation type="unfinished"></translation>
+        <translation>Rysuje elipsę w położeniu i danych średnicach</translation>
     </message>
 </context>
 </TS>
