@@ -1,40 +1,40 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>EllipseRR</name>
     <message>
         <location filename="../EllipseRR.ui" line="+17"/>
         <location filename="../EllipseRRDialog.ui" line="+129"/>
         <source>X Radius:</source>
-        <translation type="unfinished"></translation>
+        <translation>Promień X:</translation>
     </message>
     <message>
         <location line="+23"/>
         <location filename="../EllipseRRDialog.ui" line="-10"/>
         <source>Y Radius:</source>
-        <translation type="unfinished"></translation>
+        <translation>Promień Y:</translation>
     </message>
     <message>
         <location line="+30"/>
         <location filename="../EllipseRRDialog.ui" line="-90"/>
         <source>Angle:</source>
-        <translation type="unfinished"></translation>
+        <translation>Kąt:</translation>
     </message>
     <message>
         <location line="+36"/>
         <source>Reference Point:</source>
-        <translation type="unfinished"></translation>
+        <translation>Punkt odniesienia:</translation>
     </message>
     <message>
         <location filename="../EllipseRRInit.js" line="+2"/>
         <source>Ellipse with &amp;Radii</source>
-        <translation type="unfinished"></translation>
+        <translation>Elipsa o p&amp;romieniach</translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Draw ellipse with position and radii</source>
-        <translation type="unfinished"></translation>
+        <translation>Rysuje elipsę w położeniu i o danych promieniach</translation>
     </message>
 </context>
 </TS>
