@@ -1,14 +1,14 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>Ellipse</name>
     <message>
-        <location filename="../Ellipse.js" line="+71"/>
+        <location filename="../Ellipse.js" line="+85"/>
         <source>Ellipse Tools</source>
         <translatorcomment>--google--
 Pokaz menu &quot;Elipsy&quot;</translatorcomment>
-        <translation type="unfinished">Narzędzia Elipsa</translation>
+        <translation>Narzędzia elipsy</translation>
     </message>
     <message>
         <location line="+5"/>
@@ -16,7 +16,7 @@ Pokaz menu &quot;Elipsy&quot;</translatorcomment>
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 Pokaz menu &quot;Elipsy&quot;</translatorcomment>
-        <translation type="unfinished">Pokaz menu &quot;Elipsy&quot;</translation>
+        <translation>Wyświetla narzędzia elipsy</translation>
     </message>
     <message>
         <location line="+18"/>
@@ -25,7 +25,7 @@ Pokaz menu &quot;Elipsy&quot;</translatorcomment>
 --file: qcad_pl.ts--
 &amp;Elipsa
 Łuk &amp;elipsoidalny (oś)</translatorcomment>
-        <translation type="unfinished">&amp;Elipsa</translation>
+        <translation>&amp;Elipsa</translation>
     </message>
 </context>
 </TS>
