@@ -1,31 +1,31 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>LineTangent2</name>
     <message>
         <location filename="../LineTangent2.js" line="+70"/>
         <source>Choose first circle or arc</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Wybierz pierwszego okręgu lub łuku</translation>
+        <translation>Proszę wskazać pierwszy okrąg lub łuk</translation>
     </message>
     <message>
         <location line="+11"/>
         <source>Choose second circle or arc</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Wybierz sekundy okrąg lub łuk</translation>
+        <translation>Proszę wskazać drugi okrąg lub łuk</translation>
     </message>
     <message>
         <location line="+140"/>
         <source>No tangent possible</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">No styczna możliwe</translation>
+        <translation>Brak możliwej stycznej</translation>
     </message>
     <message>
         <location filename="../LineTangent2Init.js" line="+2"/>
         <source>Tan&amp;gent (Two Circles)</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Tangent (dwa koła)</translation>
+        <translation>S&amp;tyczna (dwa okręgi)</translation>
     </message>
     <message>
         <location line="+4"/>
@@ -33,7 +33,7 @@
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 Rysuj styczną (okrąg, okrąg)</translatorcomment>
-        <translation type="unfinished">Rysuj styczną (okrąg, okrąg)</translation>
+        <translation>Rysuje linię styczną do dwóch okręgów</translation>
     </message>
 </context>
 </TS>
