@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>Point1P</name>
     <message>
@@ -11,19 +11,19 @@
 Wskaż położenie linii wymiarowej lub wprowadź kąt:
 Wskaż położenie linii wymiarowej lub wprowadź kąt
 Wskaż pozycje</translatorcomment>
-        <translation type="unfinished">Położenie</translation>
+        <translation>Położenie</translation>
     </message>
     <message>
         <location filename="../Point1PInit.js" line="+2"/>
         <source>Single &amp;Point</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Single Point</translation>
+        <translation>Pojedynczy p&amp;unkt</translation>
     </message>
     <message>
         <location line="+4"/>
         <source>Draw single point</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Narysuj jeden punkt</translation>
+        <translation>Rysuje pojedynczy punkt</translation>
     </message>
 </context>
 </TS>
