@@ -1,22 +1,22 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="cs_CZ">
+<TS version="2.1" language="cs">
 <context>
     <name>Point</name>
     <message>
         <location filename="../Point.js" line="+71"/>
         <source>Point Tools</source>
-        <translation type="unfinished"></translation>
+        <translation>Nástroje bodu</translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Show point tools</source>
-        <translation type="unfinished"></translation>
+        <translation>Zobrazit nástroje bodu</translation>
     </message>
     <message>
         <location line="+22"/>
         <source>&amp;Point</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Bod</translation>
     </message>
 </context>
 </TS>
