@@ -1,19 +1,19 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>Point</name>
     <message>
         <location filename="../Point.js" line="+71"/>
         <source>Point Tools</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Narzędzia punkt</translation>
+        <translation>Narzędzia punktu</translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Show point tools</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Pokaż narzędzi punktowych</translation>
+        <translation>Wyświetla narzędzia punktu</translation>
     </message>
     <message>
         <location line="+22"/>
@@ -22,7 +22,7 @@
 --file: qcad_pl.ts--
 &amp;Punkt
 Środek, &amp;punkt</translatorcomment>
-        <translation type="unfinished">&amp;Punkt</translation>
+        <translation>&amp;Punkt</translation>
     </message>
 </context>
 </TS>
