@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>Polyline</name>
     <message>
@@ -8,7 +8,7 @@
         <source>Polyline Tools</source>
         <translatorcomment>--google--
 Pokaż menu &quot;Łamane&quot;</translatorcomment>
-        <translation type="unfinished">Narzędzia polilinii</translation>
+        <translation>Narzędzia linii łamanej</translation>
     </message>
     <message>
         <location line="+5"/>
@@ -16,7 +16,7 @@ Pokaż menu &quot;Łamane&quot;</translatorcomment>
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 Pokaż menu &quot;Łamane&quot;</translatorcomment>
-        <translation type="unfinished">Pokaż menu &quot;Łamane&quot;</translation>
+        <translation>Wyświetla narzędzia linii łamanej</translation>
     </message>
     <message>
         <location line="+22"/>
@@ -24,7 +24,7 @@ Pokaż menu &quot;Łamane&quot;</translatorcomment>
         <translatorcomment>--exact match--
 --file: qcadactions_pl.ts--
 Linia ł&amp;amana</translatorcomment>
-        <translation type="unfinished">Linia ł&amp;amana</translation>
+        <translation>Linia ł&amp;amana</translation>
     </message>
 </context>
 </TS>
