@@ -4,7 +4,7 @@
 <context>
     <name>Shape</name>
     <message>
-        <location filename="../Shape.js" line="+74"/>
+        <location filename="../Shape.js" line="+75"/>
         <source>Shape Tools</source>
         <translation type="unfinished"></translation>
     </message>
@@ -23,5 +23,10 @@
         <source>Create polyline</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location line="+10"/>
+        <source>Fill</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
