@@ -1,13 +1,13 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>Dialog</name>
     <message>
         <location filename="../TextDialog/CharacterMapDialog.ui" line="+14"/>
         <source>Character Map</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Tablica znaków</translation>
+        <translation>Tablica znaków</translation>
     </message>
 </context>
 <context>
@@ -20,7 +20,7 @@
 Wskaż położenie linii wymiarowej lub wprowadź kąt:
 Wskaż położenie linii wymiarowej lub wprowadź kąt
 Wskaż pozycje</translatorcomment>
-        <translation type="unfinished">Położenie</translation>
+        <translation>Położenie</translation>
     </message>
     <message>
         <location filename="../Text.ui" line="+17"/>
@@ -29,7 +29,7 @@ Wskaż pozycje</translatorcomment>
 --file: assistant_pl.ts--
 Błąd podczas wklejania zawartości schowka: Brak głównego elementu &lt;ui&gt;.
 Błąd podczas wklejania zawartości schowka: Brak głównego elementu &lt;ui&gt;</translatorcomment>
-        <translation type="unfinished">Spis treści:</translation>
+        <translation>Zawartość:</translation>
     </message>
     <message>
         <location line="+20"/>
@@ -38,7 +38,7 @@ Błąd podczas wklejania zawartości schowka: Brak głównego elementu &lt;ui&gt
 --file: qt_pl.ts--
 Wysokość:
 Wysokość tekstu:</translatorcomment>
-        <translation type="unfinished">Wysokość:</translation>
+        <translation>Wysokość:</translation>
     </message>
     <message>
         <location line="+20"/>
@@ -47,7 +47,7 @@ Wysokość tekstu:</translatorcomment>
 --file: qcadguiqt_pl.ts--
 Wprowadź kąt:
 Wskaż położenie linii wymiarowej:</translatorcomment>
-        <translation type="unfinished">Kąt:</translation>
+        <translation>Kąt:</translation>
     </message>
     <message>
         <location filename="../TextInit.js" line="+2"/>
@@ -56,14 +56,14 @@ Wskaż położenie linii wymiarowej:</translatorcomment>
 --file: designer_pl.ts--
 &amp;Tekst
 &amp;Tekst:</translatorcomment>
-        <translation type="unfinished">&amp;Tekst</translation>
+        <translation>&amp;Tekst</translation>
     </message>
     <message>
         <location line="+4"/>
         <source>Draw text</source>
         <translatorcomment>--google--
 Rysuj obiekty tekstowe</translatorcomment>
-        <translation type="unfinished">Rysowania tekstu</translation>
+        <translation>Rysuje tekst</translation>
     </message>
 </context>
 <context>
@@ -71,15 +71,15 @@ Rysuj obiekty tekstowe</translatorcomment>
     <message>
         <location filename="../TextDialog/TextDialog.js" line="+242"/>
         <source>Default value:</source>
-        <translation type="unfinished"></translation>
+        <translation>Domyślna wartość:</translation>
     </message>
     <message>
-        <location line="+260"/>
+        <location line="+266"/>
         <source>&amp;Undo</source>
         <translatorcomment>--exact match--
 --file: qt_pl.ts--
 &amp;Cofnij</translatorcomment>
-        <translation type="unfinished">&amp;Cofnij</translation>
+        <translation>&amp;Cofnij</translation>
     </message>
     <message>
         <location line="+4"/>
@@ -87,7 +87,7 @@ Rysuj obiekty tekstowe</translatorcomment>
         <translatorcomment>--exact match--
 --file: qt_pl.ts--
 &amp;Przywróć</translatorcomment>
-        <translation type="unfinished">&amp;Przywróć</translation>
+        <translation>&amp;Ponów</translation>
     </message>
     <message>
         <location line="+4"/>
@@ -96,7 +96,7 @@ Rysuj obiekty tekstowe</translatorcomment>
 --file: qt_pl.ts--
 W&amp;ytnij
 Wy&amp;tnij z punktem odniesienia</translatorcomment>
-        <translation type="unfinished">W&amp;ytnij</translation>
+        <translation>Wy&amp;tnij</translation>
     </message>
     <message>
         <location line="+4"/>
@@ -105,7 +105,7 @@ Wy&amp;tnij z punktem odniesienia</translatorcomment>
 --file: qt_pl.ts--
 S&amp;kopiuj
 Kopiuj z punktem &amp;odniesienia</translatorcomment>
-        <translation type="unfinished">S&amp;kopiuj</translation>
+        <translation>S&amp;kopiuj</translation>
     </message>
     <message>
         <location line="+4"/>
@@ -113,50 +113,50 @@ Kopiuj z punktem &amp;odniesienia</translatorcomment>
         <translatorcomment>--exact match--
 --file: qt_pl.ts--
 &amp;Wklej</translatorcomment>
-        <translation type="unfinished">&amp;Wklej</translation>
+        <translation>Wkl&amp;ej</translation>
     </message>
     <message>
         <location line="+8"/>
         <source>&amp;Bold</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Śmiały</translation>
+        <translation>&amp;Pogrubienie</translation>
     </message>
     <message>
         <location line="+9"/>
         <source>&amp;Italic</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Italic</translation>
+        <translation>&amp;Kursywa</translation>
     </message>
     <message>
         <location line="+20"/>
         <source>&amp;Subscript</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Indeks</translation>
+        <translation>Indeks &amp;dolny</translation>
     </message>
     <message>
         <location line="+6"/>
         <source>&amp;Superscript</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Napisany u góry</translation>
+        <translation>Indeks gó&amp;rny</translation>
     </message>
     <message>
         <location line="+18"/>
         <source>&amp;Color...</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Kolor ...</translation>
+        <translation>&amp;Kolor...</translation>
     </message>
     <message>
         <location line="+4"/>
         <source>&amp;Special Characters...</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Znaki specjalne ...</translation>
+        <translation>Znaki &amp;specjalne...</translation>
     </message>
     <message>
-        <location line="+310"/>
+        <location line="+305"/>
         <source>Others...</source>
         <translatorcomment>--ignored ...--
 --file: qcadguiqt_pl.ts--</translatorcomment>
-        <translation type="unfinished">Inne...</translation>
+        <translation>Inne...</translation>
     </message>
     <message>
         <location line="+131"/>
@@ -165,13 +165,13 @@ Kopiuj z punktem &amp;odniesienia</translatorcomment>
 --file: qcadlib_pl.ts--
 ° (Stopień)
 Stopnie dziesiętne</translatorcomment>
-        <translation type="unfinished">Stopień</translation>
+        <translation>Stopień</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Plus-Minus</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Plus-Minus</translation>
+        <translation>Plus-minus</translation>
     </message>
     <message>
         <location line="+2"/>
@@ -180,13 +180,13 @@ Stopnie dziesiętne</translatorcomment>
 --file: qcadguiqt_pl.ts--
 Przełącz znak średnicy
 ø (Średnica)</translatorcomment>
-        <translation type="unfinished">Średnica</translation>
+        <translation>Średnica</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Almost equal</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Prawie równe</translation>
+        <translation>Prawie równe</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -194,7 +194,7 @@ Przełącz znak średnicy
         <translatorcomment>--google--
 Mnożenie wartości typu %1 przez %2 lub %3 (plus lub minus nieskończoność) jest niedozwolone.
 Mnożenie wartości typu %1 przez %2 lub %3 (plus lub minus nieskończoność) jest niedozwolone</translatorcomment>
-        <translation type="unfinished">Mnożenie</translation>
+        <translation>Mnożenie</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -203,13 +203,13 @@ Mnożenie wartości typu %1 przez %2 lub %3 (plus lub minus nieskończoność) j
 --file: qcadguiqt_pl.ts--
 ÷ (Dzielenie)
 Dzielenie (÷)</translatorcomment>
-        <translation type="unfinished">Dzielenie</translation>
+        <translation>Dzielenie</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Delta</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Delta</translation>
+        <translation>Delta</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -218,7 +218,7 @@ Dzielenie (÷)</translatorcomment>
 --file: qcadguiqt_pl.ts--
 Kopiuj obiekty do schowka
 Kopiuje obiekty do schowka z punktem odniesienia</translatorcomment>
-        <translation type="unfinished">Pi</translation>
+        <translation>Pi</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -227,42 +227,42 @@ Kopiuje obiekty do schowka z punktem odniesienia</translatorcomment>
 Selektor narzucenia niepowtarzalności W3C XML Schema
 Pole narzucenia niepowtarzalności W3C XML Schema
 %1 odwołuje się do narzucenia niepowtarzalności %2 które nie jest elementem %3 ani %4.</translatorcomment>
-        <translation type="unfinished">Tożsamość</translation>
+        <translation>Tożsamość</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Not equal</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Nie równa</translation>
+        <translation>Nie równe</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Ohm</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Om</translation>
+        <translation>Om</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Omega</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Omega</translation>
+        <translation>Omega</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Squared</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Squared</translation>
+        <translation>Do kwadratu</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Cubed</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Cubed</translation>
+        <translation>Do sześcianu</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>No-break space</source>
-        <translation type="unfinished"></translation>
+        <translation>Spacja nierozdzielająca</translation>
     </message>
     <message>
         <location filename="../TextDialog/TextDialog.ui" line="+14"/>
@@ -272,13 +272,13 @@ Pole narzucenia niepowtarzalności W3C XML Schema
 Wprowadź tekst wymiaru:
 Wprowadź tekst wymiaru
 Wprowadź tekst</translatorcomment>
-        <translation type="unfinished">Tekst</translation>
+        <translation>Tekst</translation>
     </message>
     <message>
         <location line="+14"/>
         <source>Main Font</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Główne Font</translation>
+        <translation>Główna czcionka</translation>
     </message>
     <message>
         <location line="+24"/>
@@ -287,46 +287,46 @@ Wprowadź tekst</translatorcomment>
 --file: qt_pl.ts--
 Wysokość:
 Wysokość tekstu:</translatorcomment>
-        <translation type="unfinished">Wysokość:</translation>
+        <translation>Wysokość:</translation>
     </message>
     <message>
         <location line="+7"/>
         <source>Text Height in Drawing Units</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Wysokość tekstu w jednostkach rysunku</translation>
+        <translation>Określa wysokość tekstu w jednostkach rysunku</translation>
     </message>
     <message>
         <location line="+18"/>
-        <location line="+213"/>
+        <location line="+268"/>
         <source>Bold</source>
         <translatorcomment>--exact match--
 --file: qt_pl.ts--
 Pogrubiony
 Na wpół pogrubiony</translatorcomment>
-        <translation type="unfinished">Pogrubiony</translation>
+        <translation>Pogrubienie</translation>
     </message>
     <message>
-        <location line="-206"/>
-        <location line="+219"/>
+        <location line="-261"/>
+        <location line="+274"/>
         <source>Italic</source>
         <translatorcomment>--exact match--
 --file: qt_pl.ts--
 [10300-1032F] Old Italic
 Old Italic</translatorcomment>
-        <translation type="unfinished">Kursywa</translation>
+        <translation>Kursywa</translation>
     </message>
     <message>
-        <location line="-205"/>
+        <location line="-260"/>
         <source>Text fits on one line and has no formatting</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Tekst wpisuje się w jednej linii i nie ma formatowania</translation>
+        <translation>Wpisuje tekst w jednym wierszu, bez formatowania</translation>
     </message>
     <message>
         <location line="+3"/>
         <source>Simple text
 (one line, no formatting)</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Prosty tekst (jeden wiersz, nie formatowanie)</translation>
+        <translation>Prosty tekst (jeden wiersz, nie formatowany)</translation>
     </message>
     <message>
         <location line="+21"/>
@@ -336,7 +336,7 @@ Old Italic</translatorcomment>
 Zmień tekst sformatowany...
 Zmień tekst sformatowany
 Rich Text</translatorcomment>
-        <translation type="unfinished">Rich Text</translation>
+        <translation>Tekst sformatowany</translation>
     </message>
     <message>
         <location line="+36"/>
@@ -345,7 +345,7 @@ Rich Text</translatorcomment>
 --file: qt_pl.ts--
 Wytnij
 Wytnij obiekty do schowka</translatorcomment>
-        <translation type="unfinished">Wytnij</translation>
+        <translation>Wytnij</translation>
     </message>
     <message>
         <location line="+10"/>
@@ -354,7 +354,7 @@ Wytnij obiekty do schowka</translatorcomment>
 --file: qt_pl.ts--
 Skopiuj
 S&amp;kopiuj</translatorcomment>
-        <translation type="unfinished">Skopiuj</translation>
+        <translation>Skopiuj</translation>
     </message>
     <message>
         <location line="+10"/>
@@ -363,16 +363,16 @@ S&amp;kopiuj</translatorcomment>
 --file: qt_pl.ts--
 Wklej
 &amp;Wklej</translatorcomment>
-        <translation type="unfinished">Wklej</translation>
+        <translation>Wklej</translation>
     </message>
     <message>
-        <location line="+115"/>
+        <location line="+170"/>
         <source>Ctrl+B</source>
         <translatorcomment>--exact match--
 --file: linguist_pl.ts--
 CTRL+B
 Ctrl+B</translatorcomment>
-        <translation type="unfinished">Ctrl+B</translation>
+        <translation>Ctrl+B</translation>
     </message>
     <message>
         <location line="+13"/>
@@ -380,14 +380,14 @@ Ctrl+B</translatorcomment>
         <translatorcomment>--ignored case--
 --file: designer_pl.ts--
 CTRL+I</translatorcomment>
-        <translation type="unfinished">CTRL+I</translation>
+        <translation>Ctrl+I</translation>
     </message>
     <message>
         <location line="+40"/>
         <source>Insert Symbol...</source>
         <translatorcomment>--ignored ...--
 --file: qcadguiqt_pl.ts--</translatorcomment>
-        <translation type="unfinished">Wstaw symbol...</translation>
+        <translation>Wstaw symbol...</translation>
     </message>
     <message>
         <location line="+43"/>
@@ -397,39 +397,39 @@ CTRL+I</translatorcomment>
 Ścieżki do plików źródłowych dokumentacji:
 Ścieżki do plików źródłowych dokumentacji
 Ścieżki do plików źródłowych</translatorcomment>
-        <translation type="unfinished">Źródło</translation>
+        <translation>Źródło</translation>
     </message>
     <message>
         <location line="+23"/>
         <source>Attribute Details</source>
-        <translation type="unfinished"></translation>
+        <translation>Szczegóły atrybutu</translation>
     </message>
     <message>
         <location line="+8"/>
         <source>Tag:</source>
-        <translation type="unfinished"></translation>
+        <translation>Znacznik:</translation>
     </message>
     <message>
         <location line="+17"/>
         <source>Prompt:</source>
-        <translation type="unfinished"></translation>
+        <translation>Etykieta:</translation>
     </message>
     <message>
         <location line="+17"/>
         <source>Value:</source>
-        <translation type="unfinished"></translation>
+        <translation>Wartość:</translation>
     </message>
     <message>
         <location line="+42"/>
         <source>Text Geometry</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Geometria Text</translation>
+        <translation>Geometria tekstu</translation>
     </message>
     <message>
         <location line="+6"/>
         <source>Line spacing factor:</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Współczynnik interlinia:</translation>
+        <translation>Współczynnik odstępu wierszy:</translation>
     </message>
     <message>
         <location line="+13"/>
@@ -437,7 +437,7 @@ CTRL+I</translatorcomment>
         <translatorcomment>--exact match--
 --file: qcadlib_pl.ts--
 Współczynnik odstępu między liniami</translatorcomment>
-        <translation type="unfinished">Współczynnik odstępu między liniami</translation>
+        <translation>Określa sspółczynnik odległości między wierszami</translation>
     </message>
     <message>
         <location line="+16"/>
@@ -446,7 +446,7 @@ Współczynnik odstępu między liniami</translatorcomment>
 --file: qcadguiqt_pl.ts--
 Wprowadź kąt:
 Wskaż położenie linii wymiarowej:</translatorcomment>
-        <translation type="unfinished">Kąt:</translation>
+        <translation>Kąt:</translation>
     </message>
     <message>
         <location line="+13"/>
@@ -456,7 +456,7 @@ Wskaż położenie linii wymiarowej:</translatorcomment>
 Wprowadź kąt obrotu:
 Wprowadź kąt obrotu
 Kąt obracania</translatorcomment>
-        <translation type="unfinished">Kąt obracania</translation>
+        <translation>Określa kąt obrotu</translation>
     </message>
     <message>
         <location line="+25"/>
@@ -465,7 +465,7 @@ Kąt obracania</translatorcomment>
 --file: qcadguiqt_pl.ts--
 Wyrównanie
 Wyrównanie|Pionowe</translatorcomment>
-        <translation type="unfinished">Wyrównanie</translation>
+        <translation>Wyrównanie</translation>
     </message>
     <message>
         <location line="+79"/>
@@ -473,12 +473,12 @@ Wyrównanie|Pionowe</translatorcomment>
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 Góra - środek</translatorcomment>
-        <translation type="unfinished">Góra - środek</translation>
+        <translation>Góra - środek</translation>
     </message>
     <message>
         <location line="+145"/>
         <source>Base Left</source>
-        <translation type="unfinished"></translation>
+        <translation>Podstawa - lewo</translation>
     </message>
     <message>
         <location line="-177"/>
@@ -486,17 +486,17 @@ Góra - środek</translatorcomment>
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 Góra - lewo</translatorcomment>
-        <translation type="unfinished">Góra - lewo</translation>
+        <translation>Góra - lewo</translation>
     </message>
     <message>
         <location line="+206"/>
         <source>Base Center</source>
-        <translation type="unfinished"></translation>
+        <translation>Podstawa - środek</translation>
     </message>
     <message>
         <location line="+29"/>
         <source>Base Right</source>
-        <translation type="unfinished"></translation>
+        <translation>Podstawa - prawo</translation>
     </message>
     <message>
         <location line="-145"/>
@@ -504,7 +504,7 @@ Góra - lewo</translatorcomment>
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 Góra - prawo</translatorcomment>
-        <translation type="unfinished">Góra - prawo</translation>
+        <translation>Góra - prawo</translation>
     </message>
     <message>
         <location line="+203"/>
@@ -512,7 +512,7 @@ Góra - prawo</translatorcomment>
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 Dół - środek</translatorcomment>
-        <translation type="unfinished">Dół - środek</translation>
+        <translation>Dół - środek</translation>
     </message>
     <message>
         <location line="-145"/>
@@ -520,7 +520,7 @@ Dół - środek</translatorcomment>
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 Środek - lewo</translatorcomment>
-        <translation type="unfinished">Środek - lewo</translation>
+        <translation>Środek - lewo</translation>
     </message>
     <message>
         <location line="-29"/>
@@ -528,7 +528,7 @@ Dół - środek</translatorcomment>
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 Środek - środek</translatorcomment>
-        <translation type="unfinished">Środek - środek</translation>
+        <translation>Środek - środek</translation>
     </message>
     <message>
         <location line="-58"/>
@@ -536,7 +536,7 @@ Dół - środek</translatorcomment>
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 Środek - prawo</translatorcomment>
-        <translation type="unfinished">Środek - prawo</translation>
+        <translation>Środek - prawo</translation>
     </message>
     <message>
         <location line="+203"/>
@@ -544,7 +544,7 @@ Dół - środek</translatorcomment>
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 Dół - lewo</translatorcomment>
-        <translation type="unfinished">Dół - lewo</translation>
+        <translation>Dół - lewo</translation>
     </message>
     <message>
         <location line="+58"/>
@@ -552,7 +552,7 @@ Dół - lewo</translatorcomment>
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 Dół - prawo</translatorcomment>
-        <translation type="unfinished">Dół - prawo</translation>
+        <translation>Dół - prawo</translation>
     </message>
     <message>
         <location line="+59"/>
@@ -561,7 +561,7 @@ Dół - prawo</translatorcomment>
 --file: qvfb_pl.ts--
 Anuluj
 &amp;Anuluj</translatorcomment>
-        <translation type="unfinished">Anuluj</translation>
+        <translation>Anuluj</translation>
     </message>
     <message>
         <location line="+13"/>
@@ -570,7 +570,7 @@ Anuluj
 --file: qvfb_pl.ts--
 OK
 &amp;OK</translatorcomment>
-        <translation type="unfinished">OK</translation>
+        <translation>OK</translation>
     </message>
 </context>
 </TS>
