@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="ja_JP">
+<TS version="2.1" language="ja">
 <context>
     <name>LayerCompatibility</name>
     <message>
@@ -11,22 +11,27 @@
     <message>
         <location line="+0"/>
         <source>Compatibility</source>
-        <translation type="unfinished"></translation>
+        <translation>互換性</translation>
     </message>
     <message>
         <location filename="../PreferencesPage.ui" line="+17"/>
         <source>Layer 0</source>
-        <translation type="unfinished"></translation>
+        <translation>レイヤー 0</translation>
     </message>
     <message>
         <location line="+6"/>
         <source>Layer 0 behaves like a regular layer (QCAD)</source>
-        <translation type="unfinished"></translation>
+        <translation>レイヤー0は通常のレイヤーとして振る舞う(QCAD)</translation>
     </message>
     <message>
         <location line="+10"/>
-        <source>Entities in blocks on layer 0 take on attributes of block reference (compatibility)</source>
-        <translation type="unfinished"></translation>
+        <source>Layer 0 behaves differently (best compatibility)</source>
+        <translation>レイヤー０で異なる動作（最高の互換性）</translation>
+    </message>
+    <message>
+        <location line="+25"/>
+        <source>Entities in blocks on layer 0 take on attributes and visibility of block reference.</source>
+        <translation>レイヤー０のエンティティをブロック参照の属性と見た目にします。</translation>
     </message>
 </context>
 </TS>
