@@ -1,32 +1,37 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>LayerCompatibility</name>
     <message>
         <location filename="../LayerCompatibility.js" line="+30"/>
         <source>Layer</source>
-        <translation type="unfinished"></translation>
+        <translation>Warstwa</translation>
     </message>
     <message>
         <location line="+0"/>
         <source>Compatibility</source>
-        <translation type="unfinished"></translation>
+        <translation>Zgodność</translation>
     </message>
     <message>
         <location filename="../PreferencesPage.ui" line="+17"/>
         <source>Layer 0</source>
-        <translation type="unfinished"></translation>
+        <translation>Warstwa 0</translation>
     </message>
     <message>
         <location line="+6"/>
         <source>Layer 0 behaves like a regular layer (QCAD)</source>
-        <translation type="unfinished"></translation>
+        <translation>Warstwa 0 zachowuje się jak zwykła warstwa (QCAD)</translation>
     </message>
     <message>
         <location line="+10"/>
-        <source>Entities in blocks on layer 0 take on attributes of block reference (compatibility)</source>
-        <translation type="unfinished"></translation>
+        <source>Layer 0 behaves differently (best compatibility)</source>
+        <translation>Warstwa 0 zachowuje się inaczej (najlepsza zgodność)</translation>
+    </message>
+    <message>
+        <location line="+25"/>
+        <source>Entities in blocks on layer 0 take on attributes and visibility of block reference.</source>
+        <translation>Sprawia, że obiekty w blokach na warstwie 0 przejmują atrybuty i widoczność odniesienia bloku.</translation>
     </message>
 </context>
 </TS>
