@@ -1,13 +1,13 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>Startup</name>
     <message>
         <location filename="../PreferencesPage.ui" line="+17"/>
         <source>Enable Splash Screen</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Włącz ekran powitalny</translation>
+        <translation>Ekran powitalny</translation>
     </message>
 </context>
 <context>
@@ -17,7 +17,7 @@
         <source>Startup</source>
         <translatorcomment>--google--
 Pokazuj to okno przy uruchamianiu</translatorcomment>
-        <translation type="unfinished">Startup</translation>
+        <translation>Uruchamianie</translation>
     </message>
 </context>
 </TS>
