@@ -8,9 +8,9 @@
         <translation type="obsolete">&amp;Preferenze</translation>
     </message>
     <message>
-        <location filename="../AppPreferences.js" line="+64"/>
+        <location filename="../AppPreferences.js" line="+65"/>
         <source>Application &amp;Preferences</source>
-        <translation>Preferenze &amp;Applicazione</translation>
+        <translation>Preferenze &amp;applicazione</translation>
     </message>
 </context>
 </TS>
