@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>CopyWithReference</name>
     <message>
@@ -9,7 +9,7 @@
         <translatorcomment>--ignored case--
 --file: qcadactions_pl.ts--
 Kopiuj z punktem &amp;odniesienia</translatorcomment>
-        <translation type="unfinished">Kopiuj z punktem &amp;odniesienia</translation>
+        <translation>Skopiuj z &amp;odniesieniem</translation>
     </message>
 </context>
 </TS>
