@@ -32,5 +32,10 @@
         <source>Global Linetype Scale:</source>
         <translation>Globale Linientyp Skalierung:</translation>
     </message>
+    <message>
+        <location line="+35"/>
+        <source>Scale of linetypes matches the scale of each viewport</source>
+        <translation>Skalierung der Linientypen entspricht der Skalierung der einzelnen Ansichtsfenster</translation>
+    </message>
 </context>
 </TS>
