@@ -24,5 +24,10 @@
         <source>Global Linetype Scale:</source>
         <translation>Celková mierka linkovania:</translation>
     </message>
+    <message>
+        <location line="+35"/>
+        <source>Scale of linetypes matches the scale of each viewport</source>
+        <translation>Mierka typov čiar zodpovedá mierke každého výrezu</translation>
+    </message>
 </context>
 </TS>
