@@ -1,13 +1,13 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>DrawingPreferences</name>
     <message>
         <location filename="../DrawingPreferences.js" line="+43"/>
         <source>Drawing &amp;Preferences</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Preferencje rysowania</translation>
+        <translation>Preferencje ry&amp;sowania</translation>
     </message>
 </context>
 </TS>
