@@ -9,14 +9,20 @@
         <translation>&amp;Dupliquer</translation>
     </message>
     <message>
-        <location filename="../Duplicate.js" line="+55"/>
         <source>1 entity duplicated</source>
-        <translation>Une entité a été dupliqué</translation>
+        <translation type="vanished">Une entité a été dupliqué</translation>
     </message>
     <message>
-        <location line="+3"/>
         <source>%1 entities duplicated</source>
-        <translation>%1 entités ont été dupliqués</translation>
+        <translation type="vanished">%1 entités ont été dupliqués</translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../Duplicate.js" line="+54"/>
+        <source>%n entity/ies duplicated</source>
+        <translation>
+            <numerusform>%n entité a été dupliqué</numerusform>
+            <numerusform>%n entités ont été dupliqués</numerusform>
+        </translation>
     </message>
 </context>
 </TS>
