@@ -9,14 +9,20 @@
         <translation>&amp;Duplicare</translation>
     </message>
     <message>
-        <location filename="../Duplicate.js" line="+55"/>
         <source>1 entity duplicated</source>
-        <translation>Un entità è stato duplicato</translation>
+        <translation type="vanished">Un entità è stato duplicato</translation>
     </message>
     <message>
-        <location line="+3"/>
         <source>%1 entities duplicated</source>
-        <translation>%1 entità sono stati duplicati</translation>
+        <translation type="vanished">%1 entità sono stati duplicati</translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../Duplicate.js" line="+54"/>
+        <source>%n entity/ies duplicated</source>
+        <translation>
+            <numerusform>Un entità è stato duplicato</numerusform>
+            <numerusform>%n entità sono stati duplicati</numerusform>
+        </translation>
     </message>
 </context>
 </TS>
