@@ -9,14 +9,21 @@
         <translation>&amp;Duplikovať</translation>
     </message>
     <message>
-        <location filename="../Duplicate.js" line="+55"/>
         <source>1 entity duplicated</source>
-        <translation>1 duplicitný prvok</translation>
+        <translation type="vanished">1 duplicitný prvok</translation>
     </message>
     <message>
-        <location line="+3"/>
         <source>%1 entities duplicated</source>
-        <translation>%1 duplicitné (-ých) prvky (-ov)</translation>
+        <translation type="vanished">%1 duplicitné (-ých) prvky (-ov)</translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../Duplicate.js" line="+54"/>
+        <source>%n entity/ies duplicated</source>
+        <translation>
+            <numerusform>%n duplicitný (-é) prvok (-y)</numerusform>
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
     </message>
 </context>
 </TS>
