@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>CloseFile</name>
     <message>
@@ -10,7 +10,7 @@
 --file: qt_pl.ts--
 &amp;Zamknij
 &amp;Zamknij kartę</translatorcomment>
-        <translation type="unfinished">&amp;Zamknij</translation>
+        <translation>Za&amp;mknij</translation>
     </message>
 </context>
 </TS>
