@@ -1,19 +1,19 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="ja_JP">
+<TS version="2.1" language="ja">
 <context>
     <name>ImportFile</name>
     <message>
-        <location filename="../ImportFile.js" line="+50"/>
+        <location filename="../ImportFile.js" line="+68"/>
         <source>Error while importing file %1</source>
-        <translation type="unfinished"></translation>
+        <translation>ファイルインポート中のエラー %1</translation>
     </message>
     <message>
         <source>No import filters</source>
         <translation type="vanished">インポートフィルタがありません</translation>
     </message>
     <message>
-        <location line="+20"/>
+        <location line="+23"/>
         <source>No import filters have been found. Aborting...</source>
         <translation>インポートフィルタがみつかりません。中断します...</translation>
     </message>
