@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>Print</name>
     <message>
@@ -10,13 +10,13 @@
 --file: qt_pl.ts--
 Wy&amp;drukuj...
 Wy&amp;drukuj</translatorcomment>
-        <translation type="unfinished">Wy&amp;drukuj</translation>
+        <translation>&amp;Drukuj</translation>
     </message>
     <message>
-        <location line="+6"/>
+        <location line="+7"/>
         <source>Print current drawing</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Drukuj bieżący rysunek</translation>
+        <translation>Drukuje aktualny rysunek</translation>
     </message>
 </context>
 </TS>
