@@ -13,14 +13,22 @@
         <translation>Liste &amp;löschen</translation>
     </message>
     <message>
-        <location filename="../RecentFiles.js" line="+37"/>
         <source>Load/Save</source>
-        <translation>Laden/Speichern</translation>
+        <translation type="vanished">Laden/Speichern</translation>
+    </message>
+    <message>
+        <location filename="../RecentFiles.js" line="+35"/>
+        <source>Recent Files</source>
+        <translation>Zuletzt geöffnete Dateien</translation>
     </message>
     <message>
         <location line="+0"/>
-        <source>Recent Files</source>
-        <translation>Zuletzt geöffnete Dateien</translation>
+        <source>File</source>
+        <translation>Datei</translation>
+    </message>
+    <message>
+        <source>Open/Save</source>
+        <translation type="vanished">Laden/Speichern</translation>
     </message>
     <message>
         <location filename="../RecentFilesInit.js" line="+10"/>
