@@ -13,14 +13,22 @@
         <translation>&amp;Effacer la liste</translation>
     </message>
     <message>
-        <location filename="../RecentFiles.js" line="+37"/>
         <source>Load/Save</source>
-        <translation>Charger/Enregistrer</translation>
+        <translation type="vanished">Charger/Enregistrer</translation>
+    </message>
+    <message>
+        <location filename="../RecentFiles.js" line="+35"/>
+        <source>Recent Files</source>
+        <translation>Fichiers récents</translation>
     </message>
     <message>
         <location line="+0"/>
-        <source>Recent Files</source>
-        <translation>Fichiers récents</translation>
+        <source>File</source>
+        <translation>Fichier</translation>
+    </message>
+    <message>
+        <source>Open/Save</source>
+        <translation type="vanished">Charger/Enregistrer</translation>
     </message>
     <message>
         <location filename="../RecentFilesInit.js" line="+10"/>
