@@ -10,17 +10,25 @@
         <translation>&amp;Limpe a Lista</translation>
     </message>
     <message>
-        <location filename="../RecentFiles.js" line="+37"/>
         <source>Load/Save</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation>Carregue/Grave</translation>
+        <translation type="vanished">Carregue/Grave</translation>
     </message>
     <message>
-        <location line="+0"/>
+        <location filename="../RecentFiles.js" line="+35"/>
         <source>Recent Files</source>
         <translatorcomment>--google--</translatorcomment>
         <translation>Arquivos Recentes</translation>
     </message>
+    <message>
+        <location line="+0"/>
+        <source>File</source>
+        <translation>Ficheiro</translation>
+    </message>
+    <message>
+        <source>Open/Save</source>
+        <translation type="vanished">Carregue/Grave</translation>
+    </message>
     <message>
         <location filename="../RecentFilesInit.js" line="+10"/>
         <source>Open &amp;Recent</source>
