@@ -4,14 +4,18 @@
 <context>
     <name>RecentFiles</name>
     <message>
-        <location filename="../RecentFiles.js" line="+37"/>
         <source>Load/Save</source>
-        <translation>Naloži/Shrani</translation>
+        <translation type="vanished">Naloži/Shrani</translation>
+    </message>
+    <message>
+        <location filename="../RecentFiles.js" line="+35"/>
+        <source>Recent Files</source>
+        <translation>Nedavne datoteke</translation>
     </message>
     <message>
         <location line="+0"/>
-        <source>Recent Files</source>
-        <translation>Nedavne datoteke</translation>
+        <source>File</source>
+        <translation>Datoteka</translation>
     </message>
     <message>
         <location filename="../RecentFilesInit.js" line="+51"/>
