@@ -9,13 +9,13 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../RecentFiles.js" line="+37"/>
-        <source>Load/Save</source>
+        <location filename="../RecentFiles.js" line="+35"/>
+        <source>Recent Files</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location line="+0"/>
-        <source>Recent Files</source>
+        <source>File</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
