@@ -1,37 +1,43 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="cs_CZ">
+<TS version="2.1" language="cs">
 <context>
     <name>File</name>
     <message>
         <location filename="../File.js" line="+65"/>
         <source>File Tools</source>
-        <translation type="unfinished"></translation>
+        <translation>Souborové nástroje</translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Show file tools</source>
-        <translation type="unfinished"></translation>
+        <translation>Zobrazit souborové nástroje</translation>
     </message>
     <message>
         <location line="+22"/>
         <source>&amp;File</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Soubor</translation>
     </message>
     <message>
-        <location line="+63"/>
+        <location line="+91"/>
+        <location line="+69"/>
         <source>Format:</source>
-        <translation type="unfinished"></translation>
+        <translation>Formát:</translation>
     </message>
     <message>
-        <location line="+36"/>
+        <location line="-32"/>
         <source>Overwrite File?</source>
-        <translation type="unfinished"></translation>
+        <translation>Přepsat soubor?</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
-        <translation type="unfinished"></translation>
+        <translation>Soubor &apos;%1&apos; již existuje. Přeješ si ho přepsat?</translation>
+    </message>
+    <message>
+        <location line="+20"/>
+        <source>All Files</source>
+        <translation>Všechny soubory</translation>
     </message>
 </context>
 </TS>
