@@ -19,12 +19,13 @@
         <translation>&amp;Fichero</translation>
     </message>
     <message>
-        <location line="+63"/>
+        <location line="+91"/>
+        <location line="+69"/>
         <source>Format:</source>
         <translation>Formato:</translation>
     </message>
     <message>
-        <location line="+36"/>
+        <location line="-32"/>
         <source>Overwrite File?</source>
         <translatorcomment>--exact match--
 --file: qgis_es.ts--
@@ -42,5 +43,10 @@ Sobrescribir?</translatorcomment>
 El archivo &apos;%1&apos; ya existe. ¿Desea sobreescribirlo?</translatorcomment>
         <translation>El archivo &apos;%1&apos; ya existe. ¿Desea sobreescribirlo?</translation>
     </message>
+    <message>
+        <location line="+20"/>
+        <source>All Files</source>
+        <translation>Todos los archivos</translation>
+    </message>
 </context>
 </TS>
