@@ -19,12 +19,13 @@
         <translation>&amp;File</translation>
     </message>
     <message>
-        <location line="+63"/>
+        <location line="+91"/>
+        <location line="+69"/>
         <source>Format:</source>
         <translation>Formato:</translation>
     </message>
     <message>
-        <location line="+36"/>
+        <location line="-32"/>
         <source>Overwrite File?</source>
         <translatorcomment>--exact match--
 --file: Save_it.ts--
@@ -42,5 +43,10 @@ Sovrascrivere?</translatorcomment>
 Il file &apos;%1&apos; esiste già. Vuoi sovrascriverlo?</translatorcomment>
         <translation>Il file &apos;%1&apos; esiste già. Vuoi sovrascriverlo?</translation>
     </message>
+    <message>
+        <location line="+20"/>
+        <source>All Files</source>
+        <translation>Tutti i file</translation>
+    </message>
 </context>
 </TS>
