@@ -19,12 +19,13 @@
         <translation>&amp;F ファイル</translation>
     </message>
     <message>
-        <location line="+63"/>
+        <location line="+91"/>
+        <location line="+69"/>
         <source>Format:</source>
         <translation>フォーマット:</translation>
     </message>
     <message>
-        <location line="+36"/>
+        <location line="-32"/>
         <source>Overwrite File?</source>
         <translation>ファイルを上書きしますか?</translation>
     </message>
@@ -33,5 +34,10 @@
         <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
         <translation>ファイル&apos;%1&apos;は既に存在します。 上書きしますか?</translation>
     </message>
+    <message>
+        <location line="+20"/>
+        <source>All Files</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
