@@ -19,12 +19,13 @@
         <translation>&amp;Bestand</translation>
     </message>
     <message>
-        <location line="+63"/>
+        <location line="+91"/>
+        <location line="+69"/>
         <source>Format:</source>
         <translation>Formaat:</translation>
     </message>
     <message>
-        <location line="+36"/>
+        <location line="-32"/>
         <source>Overwrite File?</source>
         <translation>Bestand overschrijven?</translation>
     </message>
@@ -33,5 +34,10 @@
         <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
         <translation>Het bestand &apos;%1&apos; bestaat al. Wilt u het overschrijven?</translation>
     </message>
+    <message>
+        <location line="+20"/>
+        <source>All Files</source>
+        <translation>Alle bestanden</translation>
+    </message>
 </context>
 </TS>
