@@ -19,12 +19,13 @@
         <translation>&amp;Súbor</translation>
     </message>
     <message>
-        <location line="+63"/>
+        <location line="+91"/>
+        <location line="+69"/>
         <source>Format:</source>
         <translation>Formát:</translation>
     </message>
     <message>
-        <location line="+36"/>
+        <location line="-32"/>
         <source>Overwrite File?</source>
         <translation>Prepísať súbor?</translation>
     </message>
@@ -33,5 +34,10 @@
         <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
         <translation>Súbor &apos;%1&apos; už existuje. Chcete ho prepísať?</translation>
     </message>
+    <message>
+        <location line="+20"/>
+        <source>All Files</source>
+        <translation>Všetky súbory</translation>
+    </message>
 </context>
 </TS>
