@@ -19,12 +19,13 @@
         <translation>&amp;Datoteka</translation>
     </message>
     <message>
-        <location line="+63"/>
+        <location line="+91"/>
+        <location line="+69"/>
         <source>Format:</source>
         <translation>Format:</translation>
     </message>
     <message>
-        <location line="+36"/>
+        <location line="-32"/>
         <source>Overwrite File?</source>
         <translation>Prepišem datoteko?</translation>
     </message>
@@ -33,5 +34,10 @@
         <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
         <translation>Datoteka &apos;%1&apos; že obstaja. Jo želite prepisat?</translation>
     </message>
+    <message>
+        <location line="+20"/>
+        <source>All Files</source>
+        <translation>Vse datoteke</translation>
+    </message>
 </context>
 </TS>
