@@ -4,7 +4,7 @@
 <context>
     <name>Information</name>
     <message>
-        <location filename="../Information.js" line="+283"/>
+        <location filename="../Information.js" line="+285"/>
         <source>Information Tools</source>
         <translation>情報ツール</translation>
     </message>
@@ -26,7 +26,7 @@
     <message>
         <location line="+17"/>
         <source>Text height:</source>
-        <translation type="unfinished"></translation>
+        <translation>テキストの高さ:</translation>
     </message>
     <message>
         <source>Text Height:</source>
