@@ -1,19 +1,19 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>Information</name>
     <message>
-        <location filename="../Information.js" line="+283"/>
+        <location filename="../Information.js" line="+285"/>
         <source>Information Tools</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Narzędzi informacyjnych</translation>
+        <translation>Narzędzia informacji</translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Show information tools</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Pokaż narzędzi informacyjnych</translation>
+        <translation>Wyświetla narzędzia informacji</translation>
     </message>
     <message>
         <location line="+22"/>
@@ -21,17 +21,17 @@
         <translatorcomment>--exact match--
 --file: qcad_pl.ts--
 &amp;Info</translatorcomment>
-        <translation type="unfinished">&amp;Info</translation>
+        <translation>&amp;Informacja</translation>
     </message>
     <message>
         <location filename="../Information.ui" line="+17"/>
         <source>Add measurement to drawing</source>
-        <translation type="unfinished"></translation>
+        <translation>Dodanie pomiaru do rysunku</translation>
     </message>
     <message>
         <location line="+17"/>
         <source>Text height:</source>
-        <translation type="unfinished"></translation>
+        <translation>Wysokość tekstu:</translation>
     </message>
 </context>
 </TS>
