@@ -22,14 +22,24 @@
 <context>
     <name>Layer</name>
     <message>
-        <location filename="../PreferencesPage.ui" line="+26"/>
+        <location filename="../PreferencesPage.ui" line="+33"/>
         <source>Default color for new layers:</source>
-        <translation type="unfinished"></translation>
+        <translation>Výchozí barva pro nové vrstvy:</translation>
     </message>
     <message>
         <location line="+17"/>
+        <source>Default lineweight for layer 0:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+14"/>
+        <source>Default color for layer 0:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="-45"/>
         <source>Default lineweight for new layers:</source>
-        <translation type="unfinished">Implicitní váha pro novou vrstvu</translation>
+        <translation>Výchozí tloušťka čáry pro nové vrstvy:</translation>
     </message>
 </context>
 </TS>
