@@ -6,7 +6,7 @@
     <message>
         <location filename="../AddLayerInit.js" line="+2"/>
         <source>&amp;Add Layer</source>
-        <translation>&amp;Aggiungi Layer</translation>
+        <translation>&amp;Aggiungi layer</translation>
     </message>
     <message>
         <location filename="../AddLayer.js" line="+35"/>
@@ -22,12 +22,22 @@
 <context>
     <name>Layer</name>
     <message>
-        <location filename="../PreferencesPage.ui" line="+26"/>
+        <location filename="../PreferencesPage.ui" line="+33"/>
         <source>Default color for new layers:</source>
         <translation>Colore predefinito per nuovi layer:</translation>
     </message>
     <message>
         <location line="+17"/>
+        <source>Default lineweight for layer 0:</source>
+        <translation>Spessore di linea predefinito per layer 0:</translation>
+    </message>
+    <message>
+        <location line="+14"/>
+        <source>Default color for layer 0:</source>
+        <translation>Colore predefinito per layer 0:</translation>
+    </message>
+    <message>
+        <location line="-45"/>
         <source>Default lineweight for new layers:</source>
         <translation>Spessore di linea predefinito per nuovi layer:</translation>
     </message>
