@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="ja_JP">
+<TS version="2.1" language="ja">
 <context>
     <name>AddLayer</name>
     <message>
@@ -22,14 +22,24 @@
 <context>
     <name>Layer</name>
     <message>
-        <location filename="../PreferencesPage.ui" line="+26"/>
+        <location filename="../PreferencesPage.ui" line="+33"/>
         <source>Default color for new layers:</source>
-        <translation type="unfinished"></translation>
+        <translation>新規レイヤーのデフォルト色:</translation>
     </message>
     <message>
         <location line="+17"/>
-        <source>Default lineweight for new layers:</source>
+        <source>Default lineweight for layer 0:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location line="+14"/>
+        <source>Default color for layer 0:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="-45"/>
+        <source>Default lineweight for new layers:</source>
+        <translation>新規レイヤーのデフォルト線太さ:</translation>
+    </message>
 </context>
 </TS>
