@@ -22,12 +22,22 @@
 <context>
     <name>Layer</name>
     <message>
-        <location filename="../PreferencesPage.ui" line="+26"/>
+        <location filename="../PreferencesPage.ui" line="+33"/>
         <source>Default color for new layers:</source>
         <translation>Standaard kleur voor nieuwe lagen:</translation>
     </message>
     <message>
         <location line="+17"/>
+        <source>Default lineweight for layer 0:</source>
+        <translation>Standaard lijndikte voor laag 0:</translation>
+    </message>
+    <message>
+        <location line="+14"/>
+        <source>Default color for layer 0:</source>
+        <translation>Standaard kleur voor laag 0:</translation>
+    </message>
+    <message>
+        <location line="-45"/>
         <source>Default lineweight for new layers:</source>
         <translation>Standaard lijndikte voor nieuwe lagen:</translation>
     </message>
