@@ -25,12 +25,22 @@
 <context>
     <name>Layer</name>
     <message>
-        <location filename="../PreferencesPage.ui" line="+26"/>
+        <location filename="../PreferencesPage.ui" line="+33"/>
         <source>Default color for new layers:</source>
         <translation>Cor padrão para novas camadas:</translation>
     </message>
     <message>
         <location line="+17"/>
+        <source>Default lineweight for layer 0:</source>
+        <translation>Espessura de linha padrão para camada 0:</translation>
+    </message>
+    <message>
+        <location line="+14"/>
+        <source>Default color for layer 0:</source>
+        <translation>Cor padrão para camada 0:</translation>
+    </message>
+    <message>
+        <location line="-45"/>
         <source>Default lineweight for new layers:</source>
         <translation>Espessura de linha padrão para novas camadas:</translation>
     </message>
