@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>RemoveLayer</name>
     <message>
@@ -13,7 +13,7 @@
     <message>
         <location filename="../RemoveLayerInit.js" line="+2"/>
         <source>&amp;Delete Layer</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Usuń warstwę</translation>
     </message>
 </context>
 </TS>
