@@ -10,8 +10,12 @@
     </message>
     <message>
         <location line="+10"/>
-        <source>Add custom property to a layer</source>
+        <source>Add Custom Property to a Layer</source>
         <translation>Dodaj prilagojeno lasnost na plast</translation>
     </message>
+    <message>
+        <source>Add custom property to a layer</source>
+        <translation type="vanished">Dodaj prilagojeno lasnost na plast</translation>
+    </message>
 </context>
 </TS>
