@@ -1,31 +1,48 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="sk_SK">
+<TS version="2.1" language="sk">
 <context>
     <name>LineDove</name>
     <message>
-        <location filename="../LineDoveInit.js" line="+6"/>
+        <location filename="../LineDoveInit.js" line="+2"/>
+        <source>&amp;Dovetail Joint from 2 Points</source>
+        <translation>&amp;Rybínový spoj z 2 bodov</translation>
+    </message>
+    <message>
+        <location line="+4"/>
         <source>Draw a dovetail joint</source>
         <translation>Nakreslite rybinový spoj</translation>
     </message>
     <message>
-        <location filename="../LineDove.js" line="+56"/>
         <source>First corner</source>
-        <translation>Prvý roh</translation>
+        <translation type="vanished">Prvý roh</translation>
     </message>
     <message>
-        <location filename="../LineDoveInit.js" line="-4"/>
         <source>&amp;Dovetail Joint</source>
-        <translation>&amp;Rybinový spoj</translation>
+        <translation type="vanished">&amp;Rybinový spoj</translation>
     </message>
     <message>
         <source>&amp;Dovetail joint</source>
         <translation type="vanished">&amp;Rybinový spoj</translation>
     </message>
     <message>
-        <location filename="../LineDove.js" line="+7"/>
         <source>Second corner</source>
-        <translation>Druhý roh</translation>
+        <translation type="vanished">Druhý roh</translation>
+    </message>
+    <message>
+        <location filename="../LineDove.js" line="+63"/>
+        <source>First point</source>
+        <translation>Prvý bod</translation>
+    </message>
+    <message>
+        <location line="+7"/>
+        <source>Second point</source>
+        <translation>Druhý bod</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Done</source>
+        <translation>Hotovo</translation>
     </message>
 </context>
 </TS>
