@@ -1,19 +1,19 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>EditText</name>
     <message>
         <location filename="../EditText.js" line="+61"/>
         <source>Choose text</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Wybierz tekst</translation>
+        <translation>Proszę wskazać tekst</translation>
     </message>
     <message>
         <location filename="../EditTextInit.js" line="+2"/>
         <source>Edit Te&amp;xt</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Edytuj tekst</translation>
+        <translation>Edytuj &amp;tekst</translation>
     </message>
     <message>
         <location line="+5"/>
@@ -21,7 +21,7 @@
         <translatorcomment>--exact match--
 --file: designer_pl.ts--
 Modyfikuj tekst</translatorcomment>
-        <translation type="unfinished">Modyfikuj tekst</translation>
+        <translation>Modyfikuje tekst</translation>
     </message>
 </context>
 </TS>
