@@ -23,6 +23,16 @@
         <source>Target point</source>
         <translation>Bestemmingspunt</translation>
     </message>
+    <message>
+        <location line="+138"/>
+        <source>No selected entities in given range</source>
+        <translation>Geen geselecteerde objecten binnen het gegeven bereik</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>No entities in given range</source>
+        <translation>Geen objecten binnen het gegeven bereik</translation>
+    </message>
     <message>
         <location filename="../StretchInit.js" line="+2"/>
         <source>&amp;Stretch</source>
