@@ -1,13 +1,13 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>TrimBoth</name>
     <message>
         <location filename="../TrimBothInit.js" line="+2"/>
         <source>Trim &amp;Both</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Tapicerka Zarówno</translation>
+        <translation>Przytnij o&amp;bydwa</translation>
     </message>
 </context>
 </TS>
