@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>Reset</name>
     <message>
@@ -10,13 +10,13 @@
 --file: qvfb_pl.ts--
 Wyzeruj
 Przywróć domyślną wartość &apos;%1&apos; w &apos;%2&apos;</translatorcomment>
-        <translation type="unfinished">Wyzeruj</translation>
+        <translation>Stan początkowy</translation>
     </message>
     <message>
         <location line="+2"/>
         <source>&amp;Reset / Idle</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Reset / Idle</translation>
+        <translation>&amp;Przywróć stan początkowy</translation>
     </message>
 </context>
 </TS>
