@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>Select</name>
     <message>
@@ -8,7 +8,7 @@
         <source>Selection Tools</source>
         <translatorcomment>--google--
 Pokaż menu &quot;Zaznacz&quot;</translatorcomment>
-        <translation type="unfinished">Narzędzia wyboru</translation>
+        <translation>Narzędzia zaznaczania</translation>
     </message>
     <message>
         <location line="+5"/>
@@ -16,13 +16,13 @@ Pokaż menu &quot;Zaznacz&quot;</translatorcomment>
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 Pokaż menu &quot;Zaznacz&quot;</translatorcomment>
-        <translation type="unfinished">Pokaż menu &quot;Zaznacz&quot;</translation>
+        <translation>Wyświetla narzędzia zaznaczania</translation>
     </message>
     <message>
         <location line="+9"/>
         <source>Selection Tools Panel</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Wybór panelu Narzędzia</translation>
+        <translation>Panel narzędzi zaznaczania</translation>
     </message>
     <message>
         <location line="+9"/>
@@ -31,7 +31,7 @@ Pokaż menu &quot;Zaznacz&quot;</translatorcomment>
 --file: qcad_pl.ts--
 &amp;Zaznacz
 &amp;Wskaźnik do zaznaczania</translatorcomment>
-        <translation type="unfinished">&amp;Zaznacz</translation>
+        <translation>&amp;Zaznaczanie</translation>
     </message>
 </context>
 </TS>
