@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>RestrictVertical</name>
     <message>
@@ -9,7 +9,7 @@
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 Ograniczenie &amp;pionowo</translatorcomment>
-        <translation type="unfinished">Ograniczenie &amp;pionowo</translation>
+        <translation>Ograniczanie p&amp;ionowo</translation>
     </message>
 </context>
 </TS>
