@@ -1,13 +1,13 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>SnapDistance</name>
     <message>
         <location filename="../SnapDistance.ui" line="+17"/>
         <source>Snap distance:</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Snap dystans:</translation>
+        <translation>Odległość przyciągania:</translation>
     </message>
     <message>
         <location filename="../SnapDistanceInit.js" line="+2"/>
@@ -16,7 +16,7 @@
 &amp;Odległość punkt - punkt
 &amp;Odległość obiektu do punktu
 Odstęp od punktów &amp;końcowych</translatorcomment>
-        <translation type="unfinished">Dystans</translation>
+        <translation>&amp;Odległość</translation>
     </message>
 </context>
 </TS>
