@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>SnapEnd</name>
     <message>
@@ -9,7 +9,7 @@
         <translatorcomment>--google--
 Punkty &amp;końcowe
 Za&amp;kończenia interpunkcyjne</translatorcomment>
-        <translation type="unfinished">Koniec</translation>
+        <translation>&amp;Koniec</translation>
     </message>
 </context>
 </TS>
