@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>SnapIntersection</name>
     <message>
@@ -9,7 +9,7 @@
         <translatorcomment>--exact match--
 --file: qcadguiqt_pl.ts--
 P&amp;rzecięcie</translatorcomment>
-        <translation type="unfinished">P&amp;rzecięcie</translation>
+        <translation>P&amp;rzecięcie</translation>
     </message>
 </context>
 </TS>
