@@ -1,13 +1,13 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>SnapPerpendicular</name>
     <message>
         <location filename="../SnapPerpendicularInit.js" line="+2"/>
         <source>&amp;Perpendicular</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Prostopadły</translation>
+        <translation>&amp;Prostopadle</translation>
     </message>
 </context>
 </TS>
