@@ -1,13 +1,13 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>IsometricGridOff</name>
     <message>
         <location filename="../IsometricGridOff.js" line="+35"/>
         <source>Isometric Grid &amp;Off</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Siatka izometryczna Off</translation>
+        <translation>&amp;Wyłączenie siatki izometrycznej</translation>
     </message>
 </context>
 </TS>
