@@ -1,13 +1,13 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>IsometricView</name>
     <message>
         <location filename="../IsometricView.js" line="+44"/>
         <source>&amp;Isometric View</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Widok izometryczny</translation>
+        <translation>Widok &amp;izometryczny</translation>
     </message>
 </context>
 </TS>
