@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="ja_JP">
+<TS version="2.1" language="ja">
 <context>
     <name>ViewToolBars</name>
     <message>
@@ -10,7 +10,7 @@
     <message>
         <location filename="../ViewToolBarsPostInit.js" line="+6"/>
         <source>&amp;Toolbars and Widgets</source>
-        <translation type="unfinished"></translation>
+        <translation>ツールバーとウィジェット</translation>
     </message>
 </context>
 </TS>
