@@ -1,27 +1,27 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="ja_JP">
+<TS version="2.1" language="ja">
 <context>
     <name>Zoom</name>
     <message>
         <location filename="../Zoom.js" line="+51"/>
         <source>Zoom</source>
-        <translation type="unfinished"></translation>
+        <translation>拡大</translation>
     </message>
     <message>
-        <location line="+12"/>
+        <location line="+14"/>
         <source>Zoom Tools</source>
-        <translation type="unfinished"></translation>
+        <translation>拡大ツール </translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Show zoom tools</source>
-        <translation type="unfinished"></translation>
+        <translation>拡大ツールを表示</translation>
     </message>
     <message>
         <location line="+23"/>
         <source>&amp;Zoom</source>
-        <translation type="unfinished"></translation>
+        <translation>拡大 (&amp;Z)</translation>
     </message>
 </context>
 </TS>
