@@ -1,22 +1,27 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="cs_CZ">
+<TS version="2.1" language="cs">
 <context>
     <name>View</name>
     <message>
         <location filename="../View.js" line="+64"/>
         <source>View Tools</source>
-        <translation type="unfinished"></translation>
+        <translation>Nástroje zobrazení</translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Show view tools</source>
-        <translation type="unfinished"></translation>
+        <translation>Zobrazit nástroje zobrazení</translation>
     </message>
     <message>
         <location line="+23"/>
-        <source>&amp;View</source>
+        <source>View</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location line="+4"/>
+        <source>&amp;View</source>
+        <translation>&amp;Zobrazit</translation>
+    </message>
 </context>
 </TS>
