@@ -6,17 +6,22 @@
     <message>
         <location filename="../View.js" line="+64"/>
         <source>View Tools</source>
-        <translation>Nástroje Náhľadu</translation>
+        <translation>Nástroje Zobrazovania</translation>
     </message>
     <message>
         <location line="+5"/>
         <source>Show view tools</source>
-        <translation>Zobraziť nástroje náhľadu</translation>
+        <translation>Zobraziť nástroje zobazovania</translation>
     </message>
     <message>
         <location line="+23"/>
+        <source>View</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+4"/>
         <source>&amp;View</source>
-        <translation>&amp;Náhľad</translation>
+        <translation>&amp;Zobraziť</translation>
     </message>
 </context>
 </TS>
