@@ -4,11 +4,11 @@
 <context>
     <name>BlockList</name>
     <message>
-        <location filename="../BlockList.js" line="+399"/>
+        <location filename="../BlockList.js" line="+453"/>
         <location line="+41"/>
         <location line="+39"/>
         <source>Block List</source>
-        <translation>Lista Blocchi</translation>
+        <translation>Lista blocchi</translation>
     </message>
     <message>
         <location line="-80"/>
