@@ -4,7 +4,7 @@
 <context>
     <name>BlockList</name>
     <message>
-        <location filename="../BlockList.js" line="+399"/>
+        <location filename="../BlockList.js" line="+453"/>
         <location line="+41"/>
         <location line="+39"/>
         <source>Block List</source>
@@ -18,12 +18,12 @@
     <message>
         <location filename="../PreferencesPage.ui" line="+17"/>
         <source>Hide internal blocks</source>
-        <translation type="unfinished"></translation>
+        <translation>内側のブロックを非表示</translation>
     </message>
     <message>
         <location line="+12"/>
         <source>Enable alternating row colors</source>
-        <translation type="unfinished"></translation>
+        <translation>行の交互色を使用する</translation>
     </message>
 </context>
 </TS>
