@@ -1,32 +1,32 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>BlockList</name>
     <message>
-        <location filename="../BlockList.js" line="+399"/>
+        <location filename="../BlockList.js" line="+453"/>
         <location line="+41"/>
         <location line="+39"/>
         <source>Block List</source>
         <translatorcomment>--exact match--
 --file: qcad_pl.ts--
 Lista bloków</translatorcomment>
-        <translation type="unfinished">Lista bloków</translation>
+        <translation>Lista bloków</translation>
     </message>
     <message>
         <location line="-80"/>
         <source>Widgets</source>
-        <translation type="unfinished"></translation>
+        <translation>Widżety</translation>
     </message>
     <message>
         <location filename="../PreferencesPage.ui" line="+17"/>
         <source>Hide internal blocks</source>
-        <translation type="unfinished"></translation>
+        <translation>Ukrycie wewnętrznych bloków</translation>
     </message>
     <message>
         <location line="+12"/>
         <source>Enable alternating row colors</source>
-        <translation type="unfinished"></translation>
+        <translation>Naprzemienne kolory wierszy</translation>
     </message>
 </context>
 </TS>
