@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2016 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2018 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -16,7 +16,8 @@
  * You should have received a copy of the GNU General Public License
  * along with QCAD.
  */
-include("../Widgets.js");
+include("scripts/sprintf.js");
+include("scripts/Widgets/Widgets.js");
 include("ListViewEventHandler.js");
 include("ItemDelegate.js");
 include("FileIconProvider.js");
@@ -306,6 +307,9 @@ LibraryBrowser.initFileSystemTab = function() {
             var menu = LibraryBrowser.createItemContextMenu(dirTree, filePath, undefined, index);
             menu.exec(QCursor.pos());
         });
+
+    dirTree.installEventFilter(new REventFilter(QEvent.KeyPress.valueOf(), true));
+    dirTree.installEventFilter(new REventFilter(QEvent.KeyRelease.valueOf(), true));
 };
 
 LibraryBrowser.updateFileSystemTab = function() {
@@ -981,6 +985,8 @@ LibraryBrowser.directoryChanged = function(selected, deselected) {
     setOverrideWaitCursor();
     LibraryBrowser.updateFsView(dirPath, model);
     restoreOverrideCursor();
+
+    RSettings.setValue("LibraryBrowser/Path", dirPath);
 };
 
 /**
@@ -1734,7 +1740,7 @@ LibraryBrowser.createItemContextMenu = function(itemView, filePath, itemId, inde
                 action = new RGuiAction(text, menu);
                 action.setData(filePath);
                 action.setRequiresDocument(false);
-                action.setScriptFile("scripts/File/OpenFile/OpenFile.js");
+                action.setScriptFile(LibraryBrowser.includeBasePath + "/../../../scripts/File/OpenFile/OpenFile.js");
                 action.setIcon(icon);
                 action.addToMenu(menu);
             }
@@ -1965,19 +1971,21 @@ LibraryBrowser.showDirectory = function(dirName) {
     }
 
     var dirModel = dirTree.model();
-    var treeIndex = dirModel.pathIndex(dirName);
-    LibraryBrowser.deselectAllDirs();
-    var selectionModel = dirTree.selectionModel();
-    var flags = new QItemSelectionModel.SelectionFlags(QItemSelectionModel.Select);
-    var idxList = LibraryBrowser.getSelectedIndexes(selectionModel);
-    selectionModel.select(treeIndex, flags);
-    while (treeIndex.isValid()) {
-        dirTree.setExpanded(treeIndex, true);
-        treeIndex = treeIndex.parent();
-        QCoreApplication.processEvents();
+    if (!isNull(dirModel)) {
+        var treeIndex = dirModel.pathIndex(dirName);
+        LibraryBrowser.deselectAllDirs();
+        var selectionModel = dirTree.selectionModel();
+        var flags = new QItemSelectionModel.SelectionFlags(QItemSelectionModel.Select);
+        var idxList = LibraryBrowser.getSelectedIndexes(selectionModel);
+        selectionModel.select(treeIndex, flags);
+        while (treeIndex.isValid()) {
+            dirTree.setExpanded(treeIndex, true);
+            treeIndex = treeIndex.parent();
+            QCoreApplication.processEvents();
+        }
+        treeIndex = dirModel.pathIndex(dirName);
+        dirTree.scrollTo(treeIndex);
     }
-    treeIndex = dirModel.pathIndex(dirName);
-    dirTree.scrollTo(treeIndex);
     listView.scrollToTop();
 };
 
@@ -2018,5 +2026,8 @@ LibraryBrowser.showFirstTime = function() {
         }
         //LibraryBrowser.firstShow = false;
         appWin.setProperty("LibraryBrowser/FirstShow", true);
+
+        var initialPath = RSettings.getStringValue("LibraryBrowser/Path", "");
+        LibraryBrowser.showDirectory(initialPath);
     }
 };
