@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>Dialog</name>
     <message>
@@ -10,7 +10,7 @@
 --file: qvfb_pl.ts--
 OK
 &amp;OK</translatorcomment>
-        <translation type="unfinished">OK</translation>
+        <translation>OK</translation>
     </message>
     <message>
         <location line="+7"/>
@@ -19,7 +19,7 @@ OK
 --file: qvfb_pl.ts--
 Anuluj
 &amp;Anuluj</translatorcomment>
-        <translation type="unfinished">Anuluj</translation>
+        <translation>Anuluj</translation>
     </message>
 </context>
 <context>
@@ -28,7 +28,7 @@ Anuluj
         <location filename="../Widgets.js" line="+56"/>
         <source>&amp;Widgets</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation type="unfinished">Widgety</translation>
+        <translation>&amp;Widżety</translation>
     </message>
 </context>
 </TS>
