@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>PreviousWindow</name>
     <message>
@@ -10,7 +10,7 @@
 --file: designer_pl.ts--
 Poprze&amp;dni widok
 Znajdź &amp;poprzednie</translatorcomment>
-        <translation type="unfinished">&amp;Poprzednie</translation>
+        <translation>&amp;Poprzednie</translation>
     </message>
 </context>
 </TS>
