@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="pl_PL">
+<TS version="2.1" language="pl">
 <context>
     <name>Window</name>
     <message>
@@ -10,7 +10,12 @@
 --file: linguist_pl.ts--
 &amp;Okna
 &amp;Okno</translatorcomment>
-        <translation type="unfinished">&amp;Okno</translation>
+        <translation>&amp;Okno</translation>
+    </message>
+    <message>
+        <location line="+13"/>
+        <source>Window Tools</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
