@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2016 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2018 by Andrew Mustun. All rights reserved.
  * 
  * Function stringToDirectDistanceEntry added 2013 by Robert S.
  *
@@ -23,7 +23,8 @@
 // ensure compatibility between scripts and script bindings.
 //requiresFramework([3,0,9,0], [3,1,0,0]);
 
-include("sprintf.js");
+// don't include sprintf.js here to keep library footprint small:
+//include("sprintf.js");
 
 if (typeof(global)==="undefined") {
     global = this;
@@ -239,6 +240,26 @@ function isBlock(obj) {
     return isOfType(obj, RBlock) || isOfType(obj, RBlockPointer);
 }
 
+/**
+ * Checks if the given object is a layout (RLayout).
+ *
+ * \return true if the given object is a layout.
+ */
+function isLayout(obj) {
+    return isOfType(obj, RLayout) || isOfType(obj, RLayoutPointer);
+}
+
+/**
+ * Checks if the given object is an RObject.
+ *
+ * \return true if the given object is an object (derived from RObject).
+ */
+function isObject(obj) {
+    return !isNull(obj) &&
+        isFunction(obj.getType) &&
+        isNumber(obj.getType());
+}
+
 /**
  * Checks if the given object is a graphics entity.
  *
@@ -247,6 +268,7 @@ function isBlock(obj) {
 function isEntity(obj) {
     return !isNull(obj) &&
         isFunction(obj.getType) && 
+        isFunction(obj.getData) &&
         isNumber(obj.getType());
 }
 
@@ -259,6 +281,7 @@ function isEntity(obj) {
 function isDimensionEntity(obj) {
     return isDimAlignedEntity(obj)
         || isDimAngularEntity(obj)
+        || isDimArcLengthEntity(obj)
         || isDimDiametricEntity(obj)
         || isDimLinearEntity(obj)
         || isDimOrdinateEntity(obj)
@@ -320,10 +343,40 @@ function isDimRadialEntity(obj) {
  * Checks if the given object is an angular dimension entity.
  * 
  * \return true if the given object is an angular dimension entity
- * (RDimAngularEntity).
+ * (RDimAngular2LEntity or RDimAngular3PEntity).
  */
 function isDimAngularEntity(obj) {
-    return isOfType(obj, RDimAngularEntity) || isOfType(obj, RDimAngularEntityPointer);
+    return isDimAngular2LEntity(obj) || isDimAngular3PEntity(obj);
+}
+
+/**
+ * Checks if the given object is an angular dimension from 2 lines entity.
+ *
+ * \return true if the given object is an angular dimension entity
+ * (RDimAngular2LEntity).
+ */
+function isDimAngular2LEntity(obj) {
+    return isOfType(obj, RDimAngular2LEntity) || isOfType(obj, RDimAngular2LEntityPointer);
+}
+
+/**
+ * Checks if the given object is an angular dimension from 3 points entity.
+ *
+ * \return true if the given object is an angular dimension entity
+ * (RDimAngular3PEntity).
+ */
+function isDimAngular3PEntity(obj) {
+    return isOfType(obj, RDimAngular3PEntity) || isOfType(obj, RDimAngular3PEntityPointer);
+}
+
+/**
+ * Checks if the given object is an arc length dimension entity.
+ *
+ * \return true if the given object is an arc length dimension entity
+ * (RDimArcLengthEntity).
+ */
+function isDimArcLengthEntity(obj) {
+    return isOfType(obj, RDimArcLengthEntity) || isOfType(obj, RDimArcLengthEntityPointer);
 }
 
 /**
@@ -526,6 +579,15 @@ function isTextEntity(obj) {
     return isOfType(obj, RTextEntity) || isOfType(obj, RTextEntityPointer);
 }
 
+/**
+ * Checks if the given object is a simple text entity.
+ *
+ * \return true if the given object is a text entity (RTextEntity) and simple.
+ */
+function isSimpleTextEntity(obj) {
+    return isTextEntity(obj) && obj.isSimple();
+}
+
 /**
  * Checks if the given object is a block reference entity.
  *
@@ -603,13 +665,10 @@ function isShape(obj) {
 /**
  * Checks if the given object is a directed shape.
  *
- * \return true if the given object is a directed shape (derived from RShape and RDirected).
+ * \return true if the given object is a directed shape.
  */
 function isDirectedShape(obj) {
-    return isShape(obj) &&
-            isFunction(obj.getStartPoint) &&
-            isFunction(obj.getEndPoint) &&
-            isFunction(obj.reverse);
+    return isShape(obj) && obj.isDirected();
 }
 
 /**
@@ -727,6 +786,20 @@ function isSplineShape(obj) {
     return isOfType(obj, RSpline) || isOfType(obj, RSplinePointer);
 }
 
+/**
+ * Checks if the given object is a closed spline shape.
+ *
+ * \return true if the given object is a closed spline shape (RSpline).
+ */
+function isClosedSplineShape(obj, tolerance) {
+    if (isNull(tolerance)) {
+        return isSplineShape(obj) && obj.isGeometricallyClosed();
+    }
+    else {
+        return isSplineShape(obj) && obj.isGeometricallyClosed(tolerance);
+    }
+}
+
 /**
  * Checks if the given object is a triangle shape.
  *
@@ -789,6 +862,12 @@ function entityTypeToString(type, plural) {
         return plural ? qsTr("Aligned Dimensions") : qsTr("Aligned Dimension");
     case RS.EntityDimAngular:
         return plural ? qsTr("Angular Dimensions") : qsTr("Angular Dimension");
+    case RS.EntityDimAngular2L:
+        return plural ? qsTr("2 Line Angular Dimensions") : qsTr("2 Line Angular Dimension");
+    case RS.EntityDimAngular3P:
+        return plural ? qsTr("3 Point Angular Dimensions") : qsTr("3 Point Angular Dimension");
+    case RS.EntityDimArcLength:
+        return plural ? qsTr("Arc Dimension") : qsTr("Arc Dimension");
     case RS.EntityDimDiametric:
         return plural ? qsTr("Diametric Dimensions") : qsTr("Diametric Dimension");
     case RS.EntityDimOrdinate:
@@ -835,70 +914,6 @@ function entityTypeToString(type, plural) {
     }
 }
 
-//function getEntityTypeProperties(type) {
-//    switch (type) {
-//    case RS.EntityAll:
-//        return REntity.getStaticPropertyTypeIds();
-//    case RS.EntityBlockReferenceEntity:
-//        return RBlockReferenceEntity.getStaticPropertyTypeIds();
-//    case RS.EntityArc:
-//        return RArcEntity.getStaticPropertyTypeIds();
-//    case RS.EntityAttribute:
-//        return RAttributeEntity.getStaticPropertyTypeIds();
-//    case RS.EntityAttributeDefinition:
-//        return RAttributeDefinitionEntity.getStaticPropertyTypeIds();
-//    case RS.EntityCircle:
-//        return RCircleEntity.getStaticPropertyTypeIds();
-//    case RS.EntityDimension:
-//        return RDimensionEntity.getStaticPropertyTypeIds();
-//    case RS.EntityDimAligned:
-//        return RDimAlignedEntity.getStaticPropertyTypeIds();
-//    case RS.EntityDimAngular:
-//        return RDimAngularEntity.getStaticPropertyTypeIds();
-//    case RS.EntityDimDiametric:
-//        return RDimDiametricEntity.getStaticPropertyTypeIds();
-//    case RS.EntityDimOrdinate:
-//        return RDimOrdinateEntity.getStaticPropertyTypeIds();
-//    case RS.EntityDimRotated:
-//        return RDimRotatedEntity.getStaticPropertyTypeIds();
-//    case RS.EntityDimRadial:
-//        return RDimRadialEntity.getStaticPropertyTypeIds();
-//    case RS.EntityEllipse:
-//        return REllipseEntity.getStaticPropertyTypeIds();
-//    case RS.EntityHatch:
-//        return RHatchEntity.getStaticPropertyTypeIds();
-//    case RS.EntityImage:
-//        return RImageEntity.getStaticPropertyTypeIds();
-//    case RS.EntityLeader:
-//        return RLeaderEntity.getStaticPropertyTypeIds();
-//    case RS.EntityLine:
-//        return RLineEntity.getStaticPropertyTypeIds();
-//    case RS.EntityPoint:
-//        return RPointEntity.getStaticPropertyTypeIds();
-//    case RS.EntityPolyline:
-//        return RPolylineEntity.getStaticPropertyTypeIds();
-//    case RS.EntitySolid:
-//        return RSolidEntity.getStaticPropertyTypeIds();
-//    case RS.EntityTrace:
-//        return RTraceEntity.getStaticPropertyTypeIds();
-//    case RS.EntityViewport:
-//        return RViewportEntity.getStaticPropertyTypeIds();
-//    case RS.EntityRay:
-//        return RRayEntity.getStaticPropertyTypeIds();
-//    case RS.EntityXLine:
-//        return RXLineEntity.getStaticPropertyTypeIds();
-//    case RS.EntitySpline:
-//        return RSplineEntity.getStaticPropertyTypeIds();
-//    case RS.EntityTextBased:
-//        return RTextBasedEntity.getStaticPropertyTypeIds();
-//    case RS.EntityText:
-//        return RTextEntity.getStaticPropertyTypeIds();
-//    case RS.EntityUnknown:
-//    default:
-//        return [];
-//    }
-//}
-
 /**
  * Checks the type of the given object.
  *
@@ -964,15 +979,20 @@ function getWidgetPath(widget) {
  * \param widget the parent widget
  * \param ca the initial array which holds some child widgets for
  *        recursive calls
+ * \param allowDuplicates True to collect widgets with same name under
+ * a different key ("MyField", "MyField_1", "MyField_2").
  * \return Array of child widgets.
  */
-function getWidgets(widget, ca) {
+function getWidgets(widget, ca, allowDuplicates) {
     if (isNull(widget) || isDeleted(widget)) {
         return undefined;
     }
+    if (isNull(allowDuplicates)) {
+        allowDuplicates = false;
+    }
 
     if (isNull(ca)) {
-        ca = new Object();
+        ca = {};
     }
     var children = widget.children();
     for (var i = 0; i < children.length; ++i) {
@@ -981,10 +1001,23 @@ function getWidgets(widget, ca) {
             continue;
         }
         if (!isNull(child.objectName) && child.objectName !== "") {
-            ca[child.objectName] = child;
+            if (isNull(ca[child.objectName]) || allowDuplicates===false) {
+                // new child or overwrite child:
+                ca[child.objectName] = child;
+            }
+            else {
+                // find alternative key for child:
+                for (var k=1; k<10000; k++) {
+                    if (isNull(ca[child.objectName + "_" + k])) {
+                        ca[child.objectName + "_" + k] = child;
+                        break;
+                    }
+                }
+            }
         }
+
         if (!isNull(child.children) && child.children().length !== 0) {
-            getWidgets(child, ca);
+            getWidgets(child, ca, allowDuplicates);
         }
     }
 
@@ -1171,6 +1204,24 @@ function deepCopy(obj) {
     return obj;
 }
 
+function hasOwnPropertyCI(obj, prop) {
+   return Object.keys(obj)
+           .filter(function (v) {
+               return v.toLowerCase() === prop.toLowerCase();
+           }).length > 0;
+}
+
+function getOwnPropertyCI(obj, prop) {
+    var ret = Object.keys(obj)
+            .filter(function (v) {
+                return v.toLowerCase() === prop.toLowerCase();
+            });
+    if (ret.length>0) {
+        return obj[ret[0]];
+    }
+    return undefined;
+}
+
 /**
  * \return A new array which contains every unique item of this array only once.
  */
@@ -1220,6 +1271,13 @@ Array.prototype.contains = function(obj, method) {
     return false;
 };
 
+/**
+ * \return True if this array contains the given string (case insensitive).
+ */
+Array.prototype.containsIgnoreCase = function(obj) {
+    return this.contains(obj, function(a,b) { return a.toUpperCase()===b.toUpperCase(); });
+};
+
 /**
  * \return Array with all elements of this array that are not also
  * in the given array (subtract).
@@ -1261,18 +1319,34 @@ Array.prototype.clear = function() {
 };
 
 /**
- * Remove the given value from the array.
+ * Remove the first match of the given value from the array.
  * \param val The value to remove.
  */
-Array.prototype.remove = function(val) {
+Array.prototype.remove = function(val, compareFunction) {
     for (var i=0; i<this.length; i++) {
-        if (this[i] == val) {
+        var match = false;
+        if (!isNull(compareFunction)) {
+            match = compareFunction(this[i], val);
+        }
+        else {
+            match = (this[i] == val);
+        }
+
+        if (match) {
             this.splice(i, 1);
             break;
         }
     }
 };
 
+/**
+ * Remove the first case insensitive match of the given string value from the array.
+ * \param val The value to remove.
+ */
+Array.prototype.removeIgnoreCase = function(val) {
+    this.remove(val, function(a,b) { return a.toUpperCase()===b.toUpperCase(); });
+};
+
 /**
  * Remove the given parameter from an array (by default 'undefined').
  * 
@@ -1310,85 +1384,18 @@ Array.prototype.sortNumerical = function() {
     Array.prototype.sort.call(this, function(a,b) { return a - b });
 }
 
-//Array.alphaNumericalSorter = function(a, b) {
-//    var aVal = parseInt(a);
-//    var bVal = parseInt(b);
-//    if (isNaN(aVal) && isNaN(bVal)) {
-//        // alphabetical:
-//        return a.localeCompare(b);
-//    }
-//    else if (isNaN(aVal)) {
-//        // text before numbers:
-//        return -1;
-//    }
-//    else if (isNaN(bVal)) {
-//        // numbers after texts:
-//        return 1;
-//    }
-//    else {
-//        // nummerical:
-//        return aVal - bVal;
-//    }
-//};
-
-/* alphanum.js (C) Brian Huisman
- * Based on the Alphanum Algorithm by David Koelle
- * The Alphanum Algorithm is discussed at http://www.DaveKoelle.com
- *
- * Distributed under same license as original
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- */
 Array.alphaNumericalSorter = function(a, b) {
-    function chunkify(t) {
-        var tz = new Array();
-        var x = 0, y = -1, n = 0, i, j;
-
-        while (i = (j = t.charAt(x++)).charCodeAt(0)) {
-            var m = (i == 46 || (i >=48 && i <= 57));
-            if (m !== n) {
-                tz[++y] = "";
-                n = m;
-            }
-            tz[y] += j;
-        }
-        return tz;
-    }
-
-    var aa = chunkify(a.toLowerCase());
-    var bb = chunkify(b.toLowerCase());
-
-    for (x = 0; aa[x] && bb[x]; x++) {
-        if (aa[x] !== bb[x]) {
-            var c = Number(aa[x]), d = Number(bb[x]);
-            if (c == aa[x] && d == bb[x]) {
-                return c - d;
-            } else return (aa[x] > bb[x]) ? 1 : -1;
-        }
-    }
-    return aa.length - bb.length;
+    return RS.compareAlphanumerical(a, b);
 };
 
 /**
  * Sorts this array with string items (case insensitive)
  */
-Array.prototype.sortCaseInsensitive = function() {
-    Array.prototype.sort.call(this, function (a, b) {
-        return a.toLowerCase().localeCompare(b.toLowerCase());
-    });
-};
+//Array.prototype.sortCaseInsensitive = function() {
+//    Array.prototype.sort.call(this, function (a, b) {
+//        return a.toLowerCase().localeCompare(b.toLowerCase());
+//    });
+//};
 
 /* Finds the intersection of two sorted arrays.
  *
@@ -1658,7 +1665,6 @@ String.prototype.regexLastIndexOf = function(regex, startpos) {
     return lastIndexOf;
 }
 
-
 /**
  * Modulo which works also for negative numbers (workaround for
  * ECMAScript modulo bug).
@@ -1667,6 +1673,14 @@ Number.prototype.mod = function(n) {
     return ((this%n)+n)%n;
 };
 
+Math.sign = Math.sign || function(x) {
+  x = +x; // convert to a number
+  if (x === 0 || isNaN(x)) {
+    return Number(x);
+  }
+  return x > 0 ? 1 : -1;
+};
+
 /**
  * Formats the given number into a locale aware string.
  */
@@ -1695,6 +1709,16 @@ function angleToString(num, decimals) {
  * Formats the given coordinate (RVector) into a locale aware string.
  */
 function coordinateToString(coordinate, decimals, relative, polar, doc) {
+    if (isNull(decimals)) {
+        decimals = 3;
+    }
+    if (isNull(relative)) {
+        relative = false;
+    }
+    if (isNull(polar)) {
+        polar = false;
+    }
+
     var first;
     var second;
     var sep;
@@ -1745,82 +1769,7 @@ function coordinateToString(coordinate, decimals, relative, polar, doc) {
  *      if str is an invalid coordinate or the RVector result.
  */
 function stringToCoordinate(relativeZero, str) {
-    var decimalPoint =
-        RSettings.getStringValue("Input/DecimalPoint", ".");
-    var cartCoordSep =
-        RSettings.getStringValue("Input/CartesianCoordinateSeparator", ",");
-    var polCoordSep =
-        RSettings.getStringValue("Input/PolarCoordinateSeparator", "<");
-    var relCoordPre =
-        RSettings.getStringValue(
-            "Input/RelativeCoordinatePrefix",
-            String.fromCharCode(64) // @ (doxygen can't cope with an @ here)
-        );
-
-    if (str.count(cartCoordSep)!==1 && str.count(polCoordSep)!==1) {
-        // not a coordinate (not an error):
-        return undefined;
-    }
-
-    str = str.trim();
-
-    if (str.length===0) {
-        return undefined;
-    }
-
-    var relative = false;
-    if (str[0]===relCoordPre) {
-        relative = true;
-        str = str.substring(1);
-    }
-
-    var sl;
-    var polar = false;
-    if (str.count(cartCoordSep)===1) {
-        sl = str.split(cartCoordSep);
-        polar = false;
-    }
-    else {
-        sl = str.split(polCoordSep);
-        polar = true;
-    }
-
-    if (sl.length!==2) {
-        // invalid coordinate:
-        return RVector.invalid;
-    }
-
-    // 'fix' decimal point:
-    if (decimalPoint!=='.') {
-        sl[0] = sl[0].replace(decimalPoint, '.');
-        sl[1] = sl[1].replace(decimalPoint, '.');
-    }
-
-    // evaluate x/y or radius/angle pair:
-    var a0 = RMath.eval(sl[0]);
-    var a1 = RMath.eval(sl[1]);
-
-    if (isNaN(a0) || isNaN(a1)) {
-        // invalid coordinate:
-        return RVector.invalid;
-    }
-
-    var pos;
-    if (polar) {
-        // polar coordinate:
-        pos = RVector.createPolar(a0,RMath.deg2rad(a1));
-    }
-    else {
-        // Cartesian coordinate:
-        pos = new RVector(a0,a1);
-    }
-
-    // relative coordinate:
-    if (relative) {
-        pos = relativeZero.operator_add(pos);
-    }
-
-    return pos;
+    return RMath.parseCoordinate(str, relativeZero);
 }
 
 /**
@@ -1994,6 +1943,11 @@ function initFontComboBox(comboBox) {
     else {
         var fontList = RFontList.getNames();
         for (var i=fontList.length-1; i>=0; --i) {
+            // ignore shape definition files:
+            if (fontList[i]==="ltypeshp" || fontList[i]==="qcadshp") {
+                continue;
+            }
+
             comboBox.insertItem(0, new QIcon(), fontList[i]);
         }
     }
@@ -2079,6 +2033,14 @@ function addDirtyFlag(title) {
 }
 
 function hasPlugin(name) {
+    // TODO: refactor:
+    if (name==="PROTOOLS") {
+        if (new QFileInfo("scripts/Pro").exists()) {
+            // PROTOOLS available not as plugins but as scripts folder:
+            return true;
+        }
+    }
+
     return RPluginLoader.hasPlugin(name);
 }
 
@@ -2139,8 +2101,86 @@ function restoreOverrideCursor() {
     }
 }
 
+function initUserShortcuts() {
+    var keys = RSettings.getAllKeys("Shortcuts");
+
+    var i, key, action;
+
+    for (i=0; i<keys.length; i++) {
+        key = keys[i];
+        action = RGuiAction.getByScriptFile(key);
+        if (isNull(action)) {
+            continue;
+        }
+
+        var match = action.getScriptFile().contains("OpenFile");
+
+        var scStringList = RSettings.getValue("Shortcuts/" + key);
+
+        if (match) qDebug("scStringList", scStringList);
+
+        // explicitely no shortcuts:
+        if (isNull(scStringList)) {
+            if (match) qDebug("explicitely no shortcuts");
+            action.setShortcuts([]);
+            continue;
+        }
+
+        if (match) qDebug("setting shortcuts to ", scStringList);
+
+        //action.setShortcutsFromStrings(scStringList);
+        //action.setShortcuts(scStringList);
+
+        var scList = [];
+        for (var k=0; k<scStringList.length; k++) {
+            var sc = new QKeySequence(scStringList[k]);
+            scList.push(sc);
+        }
+        action.setShortcuts(scList);
+    }
+
+    keys = RSettings.getAllKeys("Commands");
+
+    for (i=0; i<keys.length; i++) {
+        key = keys[i];
+        action = RGuiAction.getByScriptFile(key);
+        if (isNull(action)) {
+            continue;
+        }
+        var cmStringList = RSettings.getValue("Commands/" + key);
+
+        // explicitely no commands:
+        if (isNull(cmStringList)) {
+            action.setCommands([]);
+            continue;
+        }
+
+        action.setCommands(cmStringList);
+    }
+}
+
 function addActionsToWidgets() {
+    initUserShortcuts();
+
     var appWin = RMainWindowQt.getMainWindow();
+
+    // delete previous shortcut delegates:
+    // part of workaround for QTBUG-38256, QTBUG-57990:
+    if ((RSettings.getQtVersion()<0x050500 && RSettings.getQtVersion()>=0x050000) ||
+        (RSettings.getQtVersion()===0x050800 && RS.getSystemId()==="linux")) {
+
+        var scObjs = appWin.property("DelegatedShortcutsObjs");
+        if (!isNull(scObjs)) {
+            for (var si=0; si<scObjs.length; si++) {
+                if (isNull(scObjs[si])) {
+                    continue;
+                }
+                scObjs[si].destroy();
+            }
+        }
+        appWin.setProperty("DelegatedShortcutsObjs", []);
+    }
+
     var actions = RGuiAction.getActions();
     var widgetTypes = ["Menu", "ToolBar", "MatrixPanel", "Panel"];
     for (var c=0; c<actions.length; ++c) {
@@ -2186,16 +2226,35 @@ function addActionsToWidgets() {
             var w = appWin.findChild(wn);
             if (!isNull(w)) {
 
-                // workaround for QTBUG-38256 (action not triggered for letter based shortcuts in sub menus)
-                if (RSettings.getQtVersion()<0x050500 && RSettings.getQtVersion()>=0x050000) {
-                    if (isOfType(w.parentWidget(), QMenu)) {
-                        new QShortcut(a.shortcut, a.parentWidget(), 0, 0,  Qt.WindowShortcut).activated.connect(a, "trigger");
+                // workaround for QTBUG-38256 (action not triggered for letter based shortcuts in SUB menus):
+                // workaround for QTBUG-57990 (action not triggered for letter based shortcuts in ALL menus):
+                if ((RSettings.getQtVersion()<0x050500 && RSettings.getQtVersion()>=0x050000) ||
+                    (RSettings.getQtVersion()===0x050800 && RS.getSystemId()==="linux")) {
+
+                    if (k===0) {
+                        var shortcuts = a.shortcuts();
+
+                        var scObjs = appWin.property("DelegatedShortcutsObjs");
+                        if (isNull(scObjs)) {
+                            scObjs=[];
+                        }
+                        for (var si=0; si<shortcuts.length; si++) {
+                            var scObj = new QShortcut(shortcuts[si], a.parentWidget(), 0, 0, Qt.WindowShortcut)
+                            scObj.activated.connect(a, "trigger");
+                            scObjs.push(scObj);
+                        }
+                        appWin.setProperty("DelegatedShortcutsObjs", scObjs);
 
-                        // avoid 'Ambiguous shortcut overload' when tool buttons visible:
                         var sc = a.shortcut.toString();
                         if (sc.length>0) {
-                            a.setShortcutText(" " + sc);
+                            if (RS.getSystemId()==="linux") {
+                                a.setShortcutText("[" + sc + "]");
+                            }
+                            else {
+                                a.setShortcutText(" " + sc);
+                            }
                         }
+                        a.setProperty("DelegatedShortcuts", shortcuts);
                         a.setDefaultShortcuts([]);
                     }
                 }
@@ -2276,6 +2335,10 @@ function autoPath(path) {
     }
 }
 
+function exists(path) {
+    return new QFileInfo(autoPath(path)).exists();
+}
+
 function neutralPath(path) {
     if (path.startsWith(":/")) {
         return path.substring(2);
@@ -2321,6 +2384,56 @@ function applyTheme() {
     }
 }
 
+function readTextFile(fileName) {
+    var file = new QFile(fileName);
+    var flags = new QIODevice.OpenMode(QIODevice.ReadOnly | QIODevice.Text);
+    if (file.open(flags)) {
+        var textStream = new QTextStream(file);
+        var contents = textStream.readAll();
+        file.close();
+        return contents;
+    }
+
+    return undefined;
+}
+
+function writeTextFile(fileName, str) {
+    var file = new QFile(fileName);
+    var flags = new QIODevice.OpenMode(QIODevice.WriteOnly | QIODevice.Text);
+    if (file.open(flags)) {
+        var textStream = new QTextStream(file);
+        textStream.writeString(str);
+    }
+    file.close();
+};
+
+function getKeyboardModifiers() {
+    if (RSettings.isQt(5)) {
+        return QGuiApplication.keyboardModifiers();
+    }
+    else {
+        return QApplication.keyboardModifiers();
+    }
+};
+
+function isShiftPressed() {
+    return getKeyboardModifiers().valueOf() & Qt.ShiftModifier.valueOf();
+};
+
+// Qt 4 API workaround:
+function qsTranslate2(context, sourceText, disambiguation, n) {
+    if (RSettings.isQt(4)) {
+        if (isNull(disambiguation)) {
+            return qsTranslate(context, sourceText);
+        }
+        if (isNull(n)) {
+            return qsTranslate(context, sourceText, disambiguation);
+        }
+        return qsTranslate(context, sourceText, disambiguation, "UnicodeUTF8", n);
+    }
+    return qsTranslate(context, sourceText, disambiguation, n);
+}
+
 // fix QPlainTextEdit API for Qt 5:
 if (!isFunction(QPlainTextEdit.prototype.toPlainText)) {
     QPlainTextEdit.prototype.toPlainText = function() {
@@ -2328,7 +2441,7 @@ if (!isFunction(QPlainTextEdit.prototype.toPlainText)) {
     }
 }
 
-// add isLocalFile to API for Qt 4.7:
+// add QUrl.isLocalFile to API for Qt 4.7:
 if (!isFunction(QUrl.prototype.isLocalFile)) {
     QUrl.prototype.isLocalFile = function() {
         return this.scheme().toLowerCase()==="file";
