@@ -1,6 +1,19 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="fi">
+<context>
+    <name>Apollonius</name>
+    <message>
+        <location filename="../Apollonius.js" line="+1769"/>
+        <source>Invalid radius</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+51"/>
+        <source>No solution</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DefaultAction</name>
     <message>
@@ -34,7 +47,7 @@
         <translation>Siirrä kohde haluttuun paikkaan</translation>
     </message>
     <message>
-        <location line="+351"/>
+        <location line="+376"/>
         <source>Move Reference Point</source>
         <translation>Siirrä viite</translation>
     </message>
@@ -49,7 +62,7 @@
         <translation>Siirrä kohde</translation>
     </message>
     <message>
-        <location line="+120"/>
+        <location line="+127"/>
         <source>Editing block &apos;%1&apos;&lt;br&gt;Choose &lt;i&gt;Block &gt; Return to Main Drawing&lt;/i&gt; when done</source>
         <translation type="unfinished"></translation>
     </message>
@@ -57,19 +70,19 @@
 <context>
     <name>EAction</name>
     <message>
-        <location filename="../EAction.js" line="+62"/>
+        <location filename="../EAction.js" line="+64"/>
         <source>Back</source>
         <translation>Takaisin</translation>
     </message>
     <message>
         <location line="+1"/>
-        <location line="+2019"/>
+        <location line="+2075"/>
         <source>Cancel</source>
         <translation>Peruuta</translation>
     </message>
     <message>
-        <location line="-1746"/>
-        <location line="+137"/>
+        <location line="-1802"/>
+        <location line="+136"/>
         <source>Active Tool:</source>
         <translation>Aktiivinen työkalu:</translation>
     </message>
@@ -79,7 +92,7 @@
         <translation>Ei mitään</translation>
     </message>
     <message>
-        <location line="+645"/>
+        <location line="+662"/>
         <source>Options</source>
         <translation>Asetukset</translation>
     </message>
@@ -98,12 +111,12 @@
         <translation>CAD työkalut</translation>
     </message>
     <message>
-        <location line="+687"/>
+        <location line="+710"/>
         <source>Entity is on a locked layer.</source>
         <translation>Kohde on lukitussa tasossa.</translation>
     </message>
     <message>
-        <location line="+215"/>
+        <location line="+232"/>
         <source>Length:</source>
         <translation type="unfinished"></translation>
     </message>
@@ -179,7 +192,7 @@
         <translation type="vanished">Säde on pudonnut alle 0.0 arvon %1 samankeskisen kaaren (kaarien) jälkeen.</translation>
     </message>
     <message>
-        <location filename="../ShapeAlgorithms.js" line="+896"/>
+        <location filename="../ShapeAlgorithms.js" line="+1413"/>
         <location line="+29"/>
         <source>At least two points are identical.</source>
         <translation>Vähintään kaksi pistettä ovat samat.</translation>
@@ -195,7 +208,7 @@
         <translation>Kaari ei mahdollinen.</translation>
     </message>
     <message>
-        <location line="+24"/>
+        <location line="+19"/>
         <source>Invalid number of segments: %1.</source>
         <translation>Virheellinen määrä segmenttejä %1.</translation>
     </message>
@@ -208,7 +221,7 @@
 <context>
     <name>WidgetFactory</name>
     <message>
-        <location filename="../WidgetFactory.js" line="+975"/>
+        <location filename="../WidgetFactory.js" line="+1003"/>
         <source>Restore defaults</source>
         <translation>Palauta oletusarvot</translation>
     </message>
@@ -313,7 +326,7 @@
         <translation>Mitattu arvo</translation>
     </message>
     <message>
-        <location line="+114"/>
+        <location line="+116"/>
         <source>Left</source>
         <translation>Vasen</translation>
     </message>
@@ -358,11 +371,38 @@
         <source>Bottom</source>
         <translation>Ala</translation>
     </message>
+    <message>
+        <location line="+7"/>
+        <location line="+4"/>
+        <source>Clockwise</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="-3"/>
+        <location line="+4"/>
+        <source>Counterclockwise</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+7"/>
+        <source>Preceding</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Above</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>None</source>
+        <translation type="unfinished">Ei mitään</translation>
+    </message>
 </context>
 <context>
     <name>autostart</name>
     <message>
-        <location filename="../autostart.js" line="+320"/>
+        <location filename="../autostart.js" line="+327"/>
         <source>Loading add-on translations...</source>
         <translation>Lataamassa lisäosia käännökseen...</translation>
     </message>
@@ -382,15 +422,14 @@
         <translation>Alustetaan lisäosat:</translation>
     </message>
     <message>
-        <location line="+13"/>
         <source>Post-initializing add-ons...</source>
-        <translation>Jälki-alustetaan lisäosat...</translation>
+        <translation type="vanished">Jälki-alustetaan lisäosat...</translation>
     </message>
 </context>
 <context>
     <name>library</name>
     <message>
-        <location filename="../library.js" line="+756"/>
+        <location filename="../library.js" line="+829"/>
         <source>Objects</source>
         <translation type="unfinished"></translation>
     </message>
@@ -569,6 +608,31 @@
         <source>Angular Dimension</source>
         <translation>Kulmamitta</translation>
     </message>
+    <message>
+        <location line="+2"/>
+        <source>2 Line Angular Dimensions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>2 Line Angular Dimension</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>3 Point Angular Dimensions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>3 Point Angular Dimension</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Arc Dimension</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location line="+2"/>
         <source>Diametric Dimensions</source>
@@ -775,4 +839,22 @@
         <translation>Tuntematon kohde</translation>
     </message>
 </context>
+<context>
+    <name>simple_modify</name>
+    <message>
+        <location filename="../simple_modify.js" line="+301"/>
+        <source>First entity cannot be trimmed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Entity cannot be trimmed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>Second entity cannot be trimmed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
