@@ -1,6 +1,19 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="fr_FR">
+<context>
+    <name>Apollonius</name>
+    <message>
+        <location filename="../Apollonius.js" line="+1769"/>
+        <source>Invalid radius</source>
+        <translation>Rayon invalide</translation>
+    </message>
+    <message>
+        <location line="+51"/>
+        <source>No solution</source>
+        <translation>Aucune solution</translation>
+    </message>
+</context>
 <context>
     <name>DefaultAction</name>
     <message>
@@ -39,7 +52,7 @@
         <translation>Déplacer entité</translation>
     </message>
     <message>
-        <location line="+351"/>
+        <location line="+376"/>
         <source>Move Reference Point</source>
         <translation>Déplacer référence</translation>
     </message>
@@ -54,7 +67,7 @@
         <translation>Déplacer entité</translation>
     </message>
     <message>
-        <location line="+120"/>
+        <location line="+127"/>
         <source>Editing block &apos;%1&apos;&lt;br&gt;Choose &lt;i&gt;Block &gt; Return to Main Drawing&lt;/i&gt; when done</source>
         <translation>Édition bloc &apos;%1&apos;&lt;br&gt;Choisissez &lt;i&gt;Bloc &gt; Retour au dessin principal&lt;/i&gt; lorsque vous avez terminé</translation>
     </message>
@@ -62,19 +75,19 @@
 <context>
     <name>EAction</name>
     <message>
-        <location filename="../EAction.js" line="+62"/>
+        <location filename="../EAction.js" line="+64"/>
         <source>Back</source>
         <translation>Précédent</translation>
     </message>
     <message>
         <location line="+1"/>
-        <location line="+2019"/>
+        <location line="+2075"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location line="-1746"/>
-        <location line="+137"/>
+        <location line="-1802"/>
+        <location line="+136"/>
         <source>Active Tool:</source>
         <translation>Outil actif:</translation>
     </message>
@@ -89,7 +102,7 @@
         <translation>Aucun</translation>
     </message>
     <message>
-        <location line="+645"/>
+        <location line="+662"/>
         <source>Options</source>
         <translation>Options</translation>
     </message>
@@ -110,13 +123,13 @@
         <translation>Outils de CAO</translation>
     </message>
     <message>
-        <location line="+687"/>
+        <location line="+710"/>
         <source>Entity is on a locked layer.</source>
         <translatorcomment>--google--</translatorcomment>
         <translation>Entité est sur un calque verrouillé.</translation>
     </message>
     <message>
-        <location line="+215"/>
+        <location line="+232"/>
         <source>Length:</source>
         <translation>Longueur :</translation>
     </message>
@@ -201,7 +214,7 @@
         <translation type="vanished">Rayon chuté en dessous de zéro, après %1 arc(s) concentrique(s).</translation>
     </message>
     <message>
-        <location filename="../ShapeAlgorithms.js" line="+896"/>
+        <location filename="../ShapeAlgorithms.js" line="+1413"/>
         <location line="+29"/>
         <source>At least two points are identical.</source>
         <translatorcomment>--google--</translatorcomment>
@@ -219,7 +232,7 @@
         <translation>Aucun arc possible.</translation>
     </message>
     <message>
-        <location line="+24"/>
+        <location line="+19"/>
         <source>Invalid number of segments: %1.</source>
         <translatorcomment>--google--</translatorcomment>
         <translation>Invalid nombre de segments :.%1.</translation>
@@ -234,7 +247,7 @@
 <context>
     <name>WidgetFactory</name>
     <message>
-        <location filename="../WidgetFactory.js" line="+975"/>
+        <location filename="../WidgetFactory.js" line="+1003"/>
         <source>Restore defaults</source>
         <translation>Restaurer les valeurs par défaut</translation>
     </message>
@@ -341,7 +354,7 @@
         <translation>Valeur mesurée</translation>
     </message>
     <message>
-        <location line="+114"/>
+        <location line="+116"/>
         <source>Left</source>
         <translation>Gauche</translation>
     </message>
@@ -386,6 +399,33 @@
         <source>Bottom</source>
         <translation>En bas</translation>
     </message>
+    <message>
+        <location line="+7"/>
+        <location line="+4"/>
+        <source>Clockwise</source>
+        <translation>Sens horaire</translation>
+    </message>
+    <message>
+        <location line="-3"/>
+        <location line="+4"/>
+        <source>Counterclockwise</source>
+        <translation>Sens antihoraire</translation>
+    </message>
+    <message>
+        <location line="+7"/>
+        <source>Preceding</source>
+        <translation>Précédent</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Above</source>
+        <translation>Au-dessus</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>None</source>
+        <translation>Aucun</translation>
+    </message>
 </context>
 <context>
     <name>autostart</name>
@@ -413,7 +453,7 @@
         <translation type="obsolete">Post-initialisation ...</translation>
     </message>
     <message>
-        <location filename="../autostart.js" line="+320"/>
+        <location filename="../autostart.js" line="+327"/>
         <source>Loading add-on translations...</source>
         <translation>Chargement add-on traductions...</translation>
     </message>
@@ -428,9 +468,8 @@
         <translation>Initialisation des add-ons...</translation>
     </message>
     <message>
-        <location line="+24"/>
         <source>Post-initializing add-ons...</source>
-        <translation>Post-initialisation...</translation>
+        <translation type="vanished">Post-initialisation...</translation>
     </message>
     <message>
         <source>Loading add-on translations ...</source>
@@ -445,7 +484,7 @@
         <translation type="obsolete">Initialisation des add-ons ...</translation>
     </message>
     <message>
-        <location line="-13"/>
+        <location line="+11"/>
         <source>Initializing add-ons:</source>
         <translation>Initialisation des add-ons :</translation>
     </message>
@@ -457,7 +496,7 @@
 <context>
     <name>library</name>
     <message>
-        <location filename="../library.js" line="+756"/>
+        <location filename="../library.js" line="+829"/>
         <source>Objects</source>
         <translation>Objets</translation>
     </message>
@@ -651,6 +690,31 @@ Dessine des cercles avec 2 points</translatorcomment>
         <source>Angular Dimensions</source>
         <translation>Cotations angulaires</translation>
     </message>
+    <message>
+        <location line="+2"/>
+        <source>2 Line Angular Dimensions</source>
+        <translation>2 lignes cotations angulaires</translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>2 Line Angular Dimension</source>
+        <translation>2 lignes cotation angulaire</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>3 Point Angular Dimensions</source>
+        <translation>3 points cotations angulaires</translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>3 Point Angular Dimension</source>
+        <translation>3 points cotation angulaire</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Arc Dimension</source>
+        <translation>Cotation de l&apos;arc</translation>
+    </message>
     <message>
         <location line="+2"/>
         <source>Diametric Dimension</source>
@@ -880,4 +944,22 @@ Impossible de fermer la séquence de lignes : nombre d&apos;entités définies e
         <translation>Entité inconnue</translation>
     </message>
 </context>
+<context>
+    <name>simple_modify</name>
+    <message>
+        <location filename="../simple_modify.js" line="+301"/>
+        <source>First entity cannot be trimmed.</source>
+        <translation>Première entité ne peut pas être ajuster.</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Entity cannot be trimmed.</source>
+        <translation>Entité ne peut pas être ajuster.</translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>Second entity cannot be trimmed.</source>
+        <translation>Deuxième entité ne peut pas être ajuster.</translation>
+    </message>
+</context>
 </TS>
