@@ -1,6 +1,19 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="ru">
+<context>
+    <name>Apollonius</name>
+    <message>
+        <location filename="../Apollonius.js" line="+1769"/>
+        <source>Invalid radius</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+51"/>
+        <source>No solution</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DefaultAction</name>
     <message>
@@ -34,7 +47,7 @@
         <translation>Переместите объект в нужное место</translation>
     </message>
     <message>
-        <location line="+351"/>
+        <location line="+376"/>
         <source>Move Reference Point</source>
         <translation>Переместить точку привязки</translation>
     </message>
@@ -49,7 +62,7 @@
         <translation>Перенести объект</translation>
     </message>
     <message>
-        <location line="+120"/>
+        <location line="+127"/>
         <source>Editing block &apos;%1&apos;&lt;br&gt;Choose &lt;i&gt;Block &gt; Return to Main Drawing&lt;/i&gt; when done</source>
         <translation>Редактируя блок &apos;%1&apos;,&lt;br&gt;Выберите &lt;i&gt;Блок &gt; Возврат к главному рисованию&lt;/i&gt;, когда закончите</translation>
     </message>
@@ -57,19 +70,19 @@
 <context>
     <name>EAction</name>
     <message>
-        <location filename="../EAction.js" line="+62"/>
+        <location filename="../EAction.js" line="+64"/>
         <source>Back</source>
         <translation>Назад</translation>
     </message>
     <message>
         <location line="+1"/>
-        <location line="+2019"/>
+        <location line="+2075"/>
         <source>Cancel</source>
         <translation>Отменить</translation>
     </message>
     <message>
-        <location line="-1746"/>
-        <location line="+137"/>
+        <location line="-1802"/>
+        <location line="+136"/>
         <source>Active Tool:</source>
         <translation>Активный инструмент:</translation>
     </message>
@@ -79,7 +92,7 @@
         <translation>Нет</translation>
     </message>
     <message>
-        <location line="+645"/>
+        <location line="+662"/>
         <source>Options</source>
         <translation>Параметры</translation>
     </message>
@@ -98,12 +111,12 @@
         <translation>Инструменты CAD</translation>
     </message>
     <message>
-        <location line="+687"/>
+        <location line="+710"/>
         <source>Entity is on a locked layer.</source>
         <translation>Объект находится на заблокированном слое.</translation>
     </message>
     <message>
-        <location line="+215"/>
+        <location line="+232"/>
         <source>Length:</source>
         <translation>Длина:</translation>
     </message>
@@ -179,7 +192,7 @@
         <translation type="vanished">Радиус уменьшился до 0.0 после %1 концентрической(их) дуг(и).</translation>
     </message>
     <message>
-        <location filename="../ShapeAlgorithms.js" line="+896"/>
+        <location filename="../ShapeAlgorithms.js" line="+1413"/>
         <location line="+29"/>
         <source>At least two points are identical.</source>
         <translation>По крайней мере две точки идентичны.</translation>
@@ -195,7 +208,7 @@
         <translation>Нет возможности для дуги.</translation>
     </message>
     <message>
-        <location line="+24"/>
+        <location line="+19"/>
         <source>Invalid number of segments: %1.</source>
         <translation>Неверное количество сегментов: %1.</translation>
     </message>
@@ -208,7 +221,7 @@
 <context>
     <name>WidgetFactory</name>
     <message>
-        <location filename="../WidgetFactory.js" line="+975"/>
+        <location filename="../WidgetFactory.js" line="+1003"/>
         <source>Restore defaults</source>
         <translation>Восстановить умолчания</translation>
     </message>
@@ -313,7 +326,7 @@
         <translation>Измеренное значение</translation>
     </message>
     <message>
-        <location line="+114"/>
+        <location line="+116"/>
         <source>Left</source>
         <translation>Левая</translation>
     </message>
@@ -358,11 +371,38 @@
         <source>Bottom</source>
         <translation>Низ</translation>
     </message>
+    <message>
+        <location line="+7"/>
+        <location line="+4"/>
+        <source>Clockwise</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="-3"/>
+        <location line="+4"/>
+        <source>Counterclockwise</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+7"/>
+        <source>Preceding</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Above</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>None</source>
+        <translation type="unfinished">Нет</translation>
+    </message>
 </context>
 <context>
     <name>autostart</name>
     <message>
-        <location filename="../autostart.js" line="+320"/>
+        <location filename="../autostart.js" line="+327"/>
         <source>Loading add-on translations...</source>
         <translation>Загрузка переводов для add-on...</translation>
     </message>
@@ -382,15 +422,14 @@
         <translation>Инициализация add-ons...</translation>
     </message>
     <message>
-        <location line="+13"/>
         <source>Post-initializing add-ons...</source>
-        <translation>Пост-инициализация add-ons...</translation>
+        <translation type="vanished">Пост-инициализация add-ons...</translation>
     </message>
 </context>
 <context>
     <name>library</name>
     <message>
-        <location filename="../library.js" line="+756"/>
+        <location filename="../library.js" line="+829"/>
         <source>Objects</source>
         <translation>Объекты</translation>
     </message>
@@ -569,6 +608,31 @@
         <source>Angular Dimension</source>
         <translation>Угловой размер</translation>
     </message>
+    <message>
+        <location line="+2"/>
+        <source>2 Line Angular Dimensions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>2 Line Angular Dimension</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>3 Point Angular Dimensions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>3 Point Angular Dimension</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Arc Dimension</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location line="+2"/>
         <source>Diametric Dimensions</source>
@@ -775,4 +839,22 @@
         <translation>Неизвестный объект</translation>
     </message>
 </context>
+<context>
+    <name>simple_modify</name>
+    <message>
+        <location filename="../simple_modify.js" line="+301"/>
+        <source>First entity cannot be trimmed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Entity cannot be trimmed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>Second entity cannot be trimmed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
