@@ -1,6 +1,19 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="sl_SI">
+<context>
+    <name>Apollonius</name>
+    <message>
+        <location filename="../Apollonius.js" line="+1769"/>
+        <source>Invalid radius</source>
+        <translation>Neveljavni polmer</translation>
+    </message>
+    <message>
+        <location line="+51"/>
+        <source>No solution</source>
+        <translation>Ni rešitve</translation>
+    </message>
+</context>
 <context>
     <name>DefaultAction</name>
     <message>
@@ -34,7 +47,7 @@
         <translation>Premakni entiteto na željeno lokacijo</translation>
     </message>
     <message>
-        <location line="+351"/>
+        <location line="+376"/>
         <source>Move Reference Point</source>
         <translation>Premakni referenčno točko</translation>
     </message>
@@ -49,7 +62,7 @@
         <translation>Premakni entiteto</translation>
     </message>
     <message>
-        <location line="+120"/>
+        <location line="+127"/>
         <source>Editing block &apos;%1&apos;&lt;br&gt;Choose &lt;i&gt;Block &gt; Return to Main Drawing&lt;/i&gt; when done</source>
         <translation>Urejanje gradnika &apos;%1&lt;br&gt;Ko boste končali, izberite&lt;i&gt;Gradnik &gt; Vrnitev na glasvno risbo&lt;/i&gt;</translation>
     </message>
@@ -57,19 +70,19 @@
 <context>
     <name>EAction</name>
     <message>
-        <location filename="../EAction.js" line="+62"/>
+        <location filename="../EAction.js" line="+64"/>
         <source>Back</source>
         <translation>Nazaj</translation>
     </message>
     <message>
         <location line="+1"/>
-        <location line="+2019"/>
+        <location line="+2075"/>
         <source>Cancel</source>
         <translation>Prekliči</translation>
     </message>
     <message>
-        <location line="-1746"/>
-        <location line="+137"/>
+        <location line="-1802"/>
+        <location line="+136"/>
         <source>Active Tool:</source>
         <translation>Aktivno orodje:</translation>
     </message>
@@ -79,7 +92,7 @@
         <translation>Brez</translation>
     </message>
     <message>
-        <location line="+645"/>
+        <location line="+662"/>
         <source>Options</source>
         <translation>Nastavitve</translation>
     </message>
@@ -98,12 +111,12 @@
         <translation>CAD orodja</translation>
     </message>
     <message>
-        <location line="+687"/>
+        <location line="+710"/>
         <source>Entity is on a locked layer.</source>
         <translation>Entiteta je na zaklenjeni plasti.</translation>
     </message>
     <message>
-        <location line="+215"/>
+        <location line="+232"/>
         <source>Length:</source>
         <translation>Dolžina:</translation>
     </message>
@@ -172,14 +185,14 @@
     <name>ShapeAlgorithms</name>
     <message>
         <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
-        <translation type="vanished">Radius je padel pod 0.0 po %1 kocentričnih krogih.</translation>
+        <translation type="vanished">Polmer je padel pod 0.0 po %1 kocentričnih krogih.</translation>
     </message>
     <message>
         <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
-        <translation type="vanished">Radius je padel pod 0.0 po %1 kocentričnih lokih.</translation>
+        <translation type="vanished">Polmer je padel pod 0.0 po %1 kocentričnih lokih.</translation>
     </message>
     <message>
-        <location filename="../ShapeAlgorithms.js" line="+896"/>
+        <location filename="../ShapeAlgorithms.js" line="+1413"/>
         <location line="+29"/>
         <source>At least two points are identical.</source>
         <translation>Vsaj dve točki sta identični.</translation>
@@ -195,7 +208,7 @@
         <translation>Noben lok ni možen.</translation>
     </message>
     <message>
-        <location line="+24"/>
+        <location line="+19"/>
         <source>Invalid number of segments: %1.</source>
         <translation>%1 neveljavnih segmentov.</translation>
     </message>
@@ -208,7 +221,7 @@
 <context>
     <name>WidgetFactory</name>
     <message>
-        <location filename="../WidgetFactory.js" line="+975"/>
+        <location filename="../WidgetFactory.js" line="+1003"/>
         <source>Restore defaults</source>
         <translation>Obnovi privzeto</translation>
     </message>
@@ -313,7 +326,7 @@
         <translation>Izmerjena vrednost</translation>
     </message>
     <message>
-        <location line="+114"/>
+        <location line="+116"/>
         <source>Left</source>
         <translation>Levo</translation>
     </message>
@@ -358,11 +371,38 @@
         <source>Bottom</source>
         <translation>Spodaj</translation>
     </message>
+    <message>
+        <location line="+7"/>
+        <location line="+4"/>
+        <source>Clockwise</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="-3"/>
+        <location line="+4"/>
+        <source>Counterclockwise</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+7"/>
+        <source>Preceding</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Above</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>None</source>
+        <translation type="unfinished">Brez</translation>
+    </message>
 </context>
 <context>
     <name>autostart</name>
     <message>
-        <location filename="../autostart.js" line="+320"/>
+        <location filename="../autostart.js" line="+327"/>
         <source>Loading add-on translations...</source>
         <translation>Nalagam prevode dodatkov...</translation>
     </message>
@@ -382,15 +422,14 @@
         <translation>Inicializacija dodatkov:</translation>
     </message>
     <message>
-        <location line="+13"/>
         <source>Post-initializing add-ons...</source>
-        <translation>Post-inicializacija dodatkov...</translation>
+        <translation type="vanished">Post-inicializacija dodatkov...</translation>
     </message>
 </context>
 <context>
     <name>library</name>
     <message>
-        <location filename="../library.js" line="+756"/>
+        <location filename="../library.js" line="+829"/>
         <source>Objects</source>
         <translation>Objekti</translation>
     </message>
@@ -569,6 +608,31 @@
         <source>Angular Dimension</source>
         <translation>Dimenzija kota</translation>
     </message>
+    <message>
+        <location line="+2"/>
+        <source>2 Line Angular Dimensions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>2 Line Angular Dimension</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>3 Point Angular Dimensions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>3 Point Angular Dimension</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Arc Dimension</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location line="+2"/>
         <source>Diametric Dimensions</source>
@@ -722,12 +786,12 @@
     <message>
         <location line="+2"/>
         <source>Faces</source>
-        <translation type="unfinished"></translation>
+        <translation>Površine</translation>
     </message>
     <message>
         <location line="+0"/>
         <source>Face</source>
-        <translation type="unfinished"></translation>
+        <translation>Površina</translation>
     </message>
     <message>
         <location line="+2"/>
@@ -775,4 +839,22 @@
         <translation>Neznana entiteta</translation>
     </message>
 </context>
+<context>
+    <name>simple_modify</name>
+    <message>
+        <location filename="../simple_modify.js" line="+301"/>
+        <source>First entity cannot be trimmed.</source>
+        <translation>Prve entitete ni mogoče porezat.</translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Entity cannot be trimmed.</source>
+        <translation>Entiteto ni mogoče porezat.</translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>Second entity cannot be trimmed.</source>
+        <translation>Druge entitete ni mogoče porezat.</translation>
+    </message>
+</context>
 </TS>
