@@ -1,6 +1,19 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="sv_SE">
+<context>
+    <name>Apollonius</name>
+    <message>
+        <location filename="../Apollonius.js" line="+1769"/>
+        <source>Invalid radius</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+51"/>
+        <source>No solution</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DefaultAction</name>
     <message>
@@ -34,7 +47,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+351"/>
+        <location line="+376"/>
         <source>Move Reference Point</source>
         <translation type="unfinished"></translation>
     </message>
@@ -49,7 +62,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+120"/>
+        <location line="+127"/>
         <source>Editing block &apos;%1&apos;&lt;br&gt;Choose &lt;i&gt;Block &gt; Return to Main Drawing&lt;/i&gt; when done</source>
         <translation type="unfinished"></translation>
     </message>
@@ -57,19 +70,19 @@
 <context>
     <name>EAction</name>
     <message>
-        <location filename="../EAction.js" line="+62"/>
+        <location filename="../EAction.js" line="+64"/>
         <source>Back</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location line="+1"/>
-        <location line="+2019"/>
+        <location line="+2075"/>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-1746"/>
-        <location line="+137"/>
+        <location line="-1802"/>
+        <location line="+136"/>
         <source>Active Tool:</source>
         <translation type="unfinished"></translation>
     </message>
@@ -79,7 +92,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+645"/>
+        <location line="+662"/>
         <source>Options</source>
         <translation type="unfinished"></translation>
     </message>
@@ -94,12 +107,12 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+687"/>
+        <location line="+710"/>
         <source>Entity is on a locked layer.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+215"/>
+        <location line="+232"/>
         <source>Length:</source>
         <translation type="unfinished"></translation>
     </message>
@@ -167,7 +180,7 @@
 <context>
     <name>ShapeAlgorithms</name>
     <message>
-        <location filename="../ShapeAlgorithms.js" line="+896"/>
+        <location filename="../ShapeAlgorithms.js" line="+1413"/>
         <location line="+29"/>
         <source>At least two points are identical.</source>
         <translation type="unfinished"></translation>
@@ -183,7 +196,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+24"/>
+        <location line="+19"/>
         <source>Invalid number of segments: %1.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -196,7 +209,7 @@
 <context>
     <name>WidgetFactory</name>
     <message>
-        <location filename="../WidgetFactory.js" line="+975"/>
+        <location filename="../WidgetFactory.js" line="+1003"/>
         <source>Restore defaults</source>
         <translation type="unfinished"></translation>
     </message>
@@ -301,7 +314,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+114"/>
+        <location line="+116"/>
         <source>Left</source>
         <translation type="unfinished"></translation>
     </message>
@@ -346,11 +359,38 @@
         <source>Bottom</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location line="+7"/>
+        <location line="+4"/>
+        <source>Clockwise</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="-3"/>
+        <location line="+4"/>
+        <source>Counterclockwise</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+7"/>
+        <source>Preceding</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Above</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>None</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>autostart</name>
     <message>
-        <location filename="../autostart.js" line="+320"/>
+        <location filename="../autostart.js" line="+327"/>
         <source>Loading add-on translations...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -369,16 +409,11 @@
         <source>Initializing add-ons:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location line="+13"/>
-        <source>Post-initializing add-ons...</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>library</name>
     <message>
-        <location filename="../library.js" line="+756"/>
+        <location filename="../library.js" line="+829"/>
         <source>Objects</source>
         <translation type="unfinished"></translation>
     </message>
@@ -557,6 +592,31 @@
         <source>Angular Dimension</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location line="+2"/>
+        <source>2 Line Angular Dimensions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>2 Line Angular Dimension</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>3 Point Angular Dimensions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+0"/>
+        <source>3 Point Angular Dimension</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Arc Dimension</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location line="+2"/>
         <source>Diametric Dimensions</source>
@@ -763,4 +823,22 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>simple_modify</name>
+    <message>
+        <location filename="../simple_modify.js" line="+301"/>
+        <source>First entity cannot be trimmed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+3"/>
+        <source>Entity cannot be trimmed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+10"/>
+        <source>Second entity cannot be trimmed.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
