@@ -1,10 +1,10 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="fr_FR">
+<TS version="2.1" language="fr">
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/core/RUnit.cpp" line="+268"/>
+        <location filename="../src/core/RUnit.cpp" line="+273"/>
         <source>None</source>
         <translatorcomment>--exact match--
 --file: qt_fr.ts--
@@ -237,7 +237,7 @@ Cyan</translatorcomment>
         <translatorcomment>--exact match--
 --file: designer_fr.ts--
 Bleu
-Bleu : 
+Bleu&#xa0;: 
 Bluetooth</translatorcomment>
         <translation>Bleu</translation>
     </message>
@@ -333,17 +333,17 @@ Autres...</translatorcomment>
     <message>
         <location filename="../src/core/RDocumentVariables.cpp" line="+45"/>
         <source>Current Layer ID</source>
-        <translation>ID de la couche actuelle</translation>
+        <translation>ID du calque actuel</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Drawing Unit</source>
-        <translation>Unité de dessin</translation>
+        <translation>Unité de mesure du dessin</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Linetype Scale</source>
-        <translation>Échelle du type de ligne</translation>
+        <translation>Échelle du type de la ligne</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -369,17 +369,17 @@ Liste des blocs</translatorcomment>
         <translation type="obsolete">Bloc référencé</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlock.cpp" line="+62"/>
+        <location filename="../src/core/RBlock.cpp" line="+66"/>
         <location filename="../src/core/RBlockReferenceEntity.cpp" line="+1"/>
         <location line="+3"/>
-        <location filename="../src/core/RLayout.cpp" line="+77"/>
+        <location filename="../src/core/RLayout.cpp" line="+82"/>
         <location line="+3"/>
         <location line="+3"/>
         <location line="+3"/>
         <location line="+3"/>
         <location filename="../src/core/RTextBasedEntity.cpp" line="+72"/>
-        <location filename="../src/core/RViewportEntity.cpp" line="+71"/>
-        <location line="+6"/>
+        <location filename="../src/core/RViewportEntity.cpp" line="+73"/>
+        <location line="+8"/>
         <location line="+2"/>
         <source>X</source>
         <translatorcomment>--exact match--
@@ -393,7 +393,7 @@ Exportation du dessin...</translatorcomment>
         <location filename="../src/core/RBlockReferenceEntity.cpp" line="-3"/>
         <location line="+1"/>
         <location line="+1"/>
-        <location filename="../src/core/RViewportEntity.cpp" line="-8"/>
+        <location filename="../src/core/RViewportEntity.cpp" line="-10"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Position</source>
@@ -405,7 +405,12 @@ Indiquer la position [angle/longueur]</translatorcomment>
         <translation>Position</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlock.cpp" line="+0"/>
+        <location filename="../src/core/RBlock.cpp" line="-1"/>
+        <source>Pixel Unit</source>
+        <translation>Pixel unité</translation>
+    </message>
+    <message>
+        <location line="+1"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Origin</source>
@@ -422,7 +427,7 @@ Indiquer la position [angle/longueur]</translatorcomment>
         <location line="+3"/>
         <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
         <location filename="../src/core/RViewportEntity.cpp" line="-1"/>
-        <location line="+6"/>
+        <location line="+8"/>
         <location line="+2"/>
         <source>Y</source>
         <translatorcomment>--exact match--
@@ -442,8 +447,8 @@ Modifier
         <location line="+3"/>
         <location line="+3"/>
         <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
-        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
-        <location line="+8"/>
+        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
+        <location line="+10"/>
         <source>Z</source>
         <translatorcomment>--google--
 Partage &amp;Horizontal
@@ -460,14 +465,14 @@ Partage Horizontal
         <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
         <location line="+1"/>
         <location line="+1"/>
-        <location filename="../src/core/RViewportEntity.cpp" line="-5"/>
+        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
         <source>Scale</source>
         <translatorcomment>--exact match--
 --file: Scale_fr.ts--
 &amp;Echelle
 Echelle
 Met les entités à l&apos;échelle</translatorcomment>
-        <translation>Echelle</translation>
+        <translation>Échelle</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -500,8 +505,13 @@ Indiquer l&apos;angle de la ligne de cote :</translatorcomment>
         <translation>Espacement des lignes</translation>
     </message>
     <message>
-        <location filename="../src/core/REntity.cpp" line="+86"/>
-        <location filename="../src/core/RObject.cpp" line="+63"/>
+        <location line="+3"/>
+        <source>Attributes</source>
+        <translation>Attributs</translation>
+    </message>
+    <message>
+        <location filename="../src/core/REntity.cpp" line="+87"/>
+        <location filename="../src/core/RObject.cpp" line="+66"/>
         <source>Type</source>
         <translatorcomment>--exact match--
 --file: qt_fr.ts--
@@ -526,7 +536,7 @@ Liste des calques</translatorcomment>
     </message>
     <message>
         <location line="+1"/>
-        <location filename="../src/core/RLayer.cpp" line="+80"/>
+        <location filename="../src/core/RLayer.cpp" line="+99"/>
         <source>Linetype</source>
         <translatorcomment>--exact match--
 --file: LinetypeSettings_fr.ts--
@@ -577,21 +587,25 @@ Ouvrir la boîte de dialogue des couleurs</translatorcomment>
     </message>
     <message>
         <location line="-3"/>
+        <location filename="../src/core/RLayout.cpp" line="+3"/>
         <source>Left</source>
         <translation>Gauche</translation>
     </message>
     <message>
         <location line="+1"/>
+        <location filename="../src/core/RLayout.cpp" line="+1"/>
         <source>Bottom</source>
         <translation>En bas</translation>
     </message>
     <message>
         <location line="+1"/>
+        <location filename="../src/core/RLayout.cpp" line="+1"/>
         <source>Right</source>
         <translation>Droite</translation>
     </message>
     <message>
         <location line="+1"/>
+        <location filename="../src/core/RLayout.cpp" line="+1"/>
         <source>Top</source>
         <translation>En haut</translation>
     </message>
@@ -613,6 +627,7 @@ Ouvrir la boîte de dialogue des couleurs</translatorcomment>
     </message>
     <message>
         <location filename="../src/core/REntity.cpp" line="+2"/>
+        <location filename="../src/core/RLayout.cpp" line="+1"/>
         <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
         <source>Width</source>
         <translation>Largeur</translation>
@@ -625,6 +640,7 @@ Ouvrir la boîte de dialogue des couleurs</translatorcomment>
     </message>
     <message>
         <location line="+0"/>
+        <location filename="../src/core/RLayout.cpp" line="+1"/>
         <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
         <source>Height</source>
         <translation>Hauteur</translation>
@@ -704,6 +720,16 @@ Ouvrir la boîte de dialogue des couleurs</translatorcomment>
     </message>
     <message>
         <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
+        <source>Rotation</source>
+        <translation>Rotation</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>On</source>
+        <translation>Activé</translation>
+    </message>
+    <message>
+        <location line="+1"/>
         <location line="+1"/>
         <source>View Center</source>
         <translation>Affichage centre</translation>
@@ -721,23 +747,52 @@ Ouvrir la boîte de dialogue des couleurs</translatorcomment>
         <translation>Overall</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlock.cpp" line="-5"/>
-        <location filename="../src/core/RLayer.cpp" line="-3"/>
-        <location filename="../src/core/RLayout.cpp" line="-16"/>
+        <location filename="../src/core/RBlock.cpp" line="-6"/>
+        <location filename="../src/core/RLayer.cpp" line="-8"/>
+        <location filename="../src/core/RLayout.cpp" line="-24"/>
         <source>Name</source>
         <translation>Nom</translation>
     </message>
     <message>
         <location line="+1"/>
-        <location filename="../src/core/RLayer.cpp" line="+1"/>
         <source>Hidden</source>
         <translation>Caché</translation>
     </message>
     <message>
         <location filename="../src/core/RLayer.cpp" line="+1"/>
+        <source>Off</source>
+        <translation>Inactif</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Frozen</source>
+        <translation>Gelés</translation>
+    </message>
+    <message>
+        <location line="+1"/>
         <source>Locked</source>
         <translation>Verrouillée</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Collapsed</source>
+        <translation>Plié</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Plottable</source>
+        <translation>Traçable</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Snappable</source>
+        <translation>Accrochable</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Off is Freeze</source>
+        <translation>Éteint est gelé</translation>
+    </message>
     <message>
         <location filename="../src/core/RLayout.cpp" line="+1"/>
         <source>Tab Order</source>
@@ -778,14 +833,28 @@ Ouvrir la boîte de dialogue des couleurs</translatorcomment>
         <source>Max Extents</source>
         <translation>Max extents</translation>
     </message>
+    <message>
+        <source>Plot Margins</source>
+        <translation type="vanished">Marges des tracés</translation>
+    </message>
+    <message>
+        <location filename="../src/core/RBlockReferenceData.cpp" line="+627"/>
+        <source>Circular (recursive) block referencing detected:</source>
+        <translation>Une référence de bloc circulaire (récursive) a été détectée :</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Block name:</source>
+        <translation>Nom du bloc :</translation>
+    </message>
 </context>
 <context>
     <name>RGuiAction</name>
     <message>
-        <location filename="../src/core/RGuiAction.cpp" line="+182"/>
+        <location filename="../src/core/RGuiAction.cpp" line="+184"/>
         <source>Requires selection</source>
         <translatorcomment>--google--</translatorcomment>
-        <translation>Nécessite une sélection</translation>
+        <translation>Demande une sélection</translation>
     </message>
 </context>
 <context>
@@ -796,7 +865,7 @@ Ouvrir la boîte de dialogue des couleurs</translatorcomment>
     </message>
     <message>
         <source>Frozen</source>
-        <translation type="vanished">Caché</translation>
+        <translation type="vanished">Gelé</translation>
     </message>
     <message>
         <source>Hidden</source>
@@ -1003,7 +1072,7 @@ Bordure (grande)</translatorcomment>
 <context>
     <name>RLinetypePattern</name>
     <message>
-        <location filename="../src/core/RLinetypePattern.cpp" line="+845"/>
+        <location filename="../src/core/RLinetypePattern.cpp" line="+856"/>
         <source>By Layer</source>
         <translation>Par calque</translation>
     </message>
