@@ -4,7 +4,7 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/core/RUnit.cpp" line="+268"/>
+        <location filename="../src/core/RUnit.cpp" line="+273"/>
         <source>None</source>
         <translatorcomment>--exact match--
 --file: pt_PT.po--
@@ -372,7 +372,7 @@ Cinza Claro</translatorcomment>
         <location filename="../src/core/RBlockReferenceEntity.cpp" line="+93"/>
         <location line="+1"/>
         <location line="+1"/>
-        <location filename="../src/core/RViewportEntity.cpp" line="+71"/>
+        <location filename="../src/core/RViewportEntity.cpp" line="+73"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Position</source>
@@ -383,17 +383,22 @@ Indique a posição [ângulo/comprimento]</translatorcomment>
         <translation>Posição</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlock.cpp" line="+62"/>
+        <location filename="../src/core/RBlock.cpp" line="+65"/>
+        <source>Pixel Unit</source>
+        <translation>Pixel unidade</translation>
+    </message>
+    <message>
+        <location line="+1"/>
         <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
         <location line="+3"/>
-        <location filename="../src/core/RLayout.cpp" line="+77"/>
+        <location filename="../src/core/RLayout.cpp" line="+82"/>
         <location line="+3"/>
         <location line="+3"/>
         <location line="+3"/>
         <location line="+3"/>
         <location filename="../src/core/RTextBasedEntity.cpp" line="+72"/>
         <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
-        <location line="+6"/>
+        <location line="+8"/>
         <location line="+2"/>
         <source>X</source>
         <translatorcomment>--exact match--
@@ -419,8 +424,8 @@ Exportando o desenho...</translatorcomment>
         <location line="+3"/>
         <location line="+3"/>
         <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
-        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
-        <location line="+6"/>
+        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
+        <location line="+8"/>
         <location line="+2"/>
         <source>Y</source>
         <translatorcomment>--exact match--
@@ -440,8 +445,8 @@ Modifique
         <location line="+3"/>
         <location line="+3"/>
         <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
-        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
-        <location line="+8"/>
+        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
+        <location line="+10"/>
         <source>Z</source>
         <translatorcomment>Oculte (congele) todos os carimbos
 Mostre (descongele) todos os carimbos
@@ -457,7 +462,7 @@ Mostre (descongele) todos os carimbos
         <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
         <location line="+1"/>
         <location line="+1"/>
-        <location filename="../src/core/RViewportEntity.cpp" line="-5"/>
+        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
         <source>Scale</source>
         <translatorcomment>--exact match--
 --file: pt_PT.po--
@@ -495,8 +500,13 @@ Insira o ângulo da linha de dimensão:</translatorcomment>
         <translation>Espaçamento de Linha</translation>
     </message>
     <message>
-        <location filename="../src/core/REntity.cpp" line="+86"/>
-        <location filename="../src/core/RObject.cpp" line="+63"/>
+        <location line="+3"/>
+        <source>Attributes</source>
+        <translation>Atributos</translation>
+    </message>
+    <message>
+        <location filename="../src/core/REntity.cpp" line="+87"/>
+        <location filename="../src/core/RObject.cpp" line="+66"/>
         <source>Type</source>
         <translatorcomment>--exact match--
 --file: pt_PT.po--
@@ -505,7 +515,7 @@ Tipo Ordinal</translatorcomment>
         <translation>Tipo</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-11"/>
+        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-14"/>
         <source>Block</source>
         <translatorcomment>--exact match--
 --file: Block_pt.ts--
@@ -530,7 +540,7 @@ Lista de Camadas</translatorcomment>
     </message>
     <message>
         <location line="+1"/>
-        <location filename="../src/core/RLayer.cpp" line="+80"/>
+        <location filename="../src/core/RLayer.cpp" line="+99"/>
         <source>Linetype</source>
         <translatorcomment>--google--</translatorcomment>
         <translation>Tipo de Linha</translation>
@@ -578,21 +588,25 @@ Abre diálogo de cores</translatorcomment>
     </message>
     <message>
         <location line="-3"/>
+        <location filename="../src/core/RLayout.cpp" line="+3"/>
         <source>Left</source>
         <translation>Esquerda</translation>
     </message>
     <message>
         <location line="+1"/>
+        <location filename="../src/core/RLayout.cpp" line="+1"/>
         <source>Bottom</source>
         <translation>Inferior</translation>
     </message>
     <message>
         <location line="+1"/>
+        <location filename="../src/core/RLayout.cpp" line="+1"/>
         <source>Right</source>
         <translation>Direita</translation>
     </message>
     <message>
         <location line="+1"/>
+        <location filename="../src/core/RLayout.cpp" line="+1"/>
         <source>Top</source>
         <translation>Superior</translation>
     </message>
@@ -614,6 +628,7 @@ Abre diálogo de cores</translatorcomment>
     </message>
     <message>
         <location filename="../src/core/REntity.cpp" line="+2"/>
+        <location filename="../src/core/RLayout.cpp" line="+1"/>
         <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
         <source>Width</source>
         <translation>Largura</translation>
@@ -626,6 +641,7 @@ Abre diálogo de cores</translatorcomment>
     </message>
     <message>
         <location line="+0"/>
+        <location filename="../src/core/RLayout.cpp" line="+1"/>
         <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
         <source>Height</source>
         <translation>Altura</translation>
@@ -705,6 +721,16 @@ Abre diálogo de cores</translatorcomment>
     </message>
     <message>
         <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
+        <source>Rotation</source>
+        <translation>Rotação</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>On</source>
+        <translation>Ativado</translation>
+    </message>
+    <message>
+        <location line="+1"/>
         <location line="+1"/>
         <source>View Center</source>
         <translation>Ver centro</translation>
@@ -722,23 +748,52 @@ Abre diálogo de cores</translatorcomment>
         <translation>Overall</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlock.cpp" line="-5"/>
-        <location filename="../src/core/RLayer.cpp" line="-3"/>
-        <location filename="../src/core/RLayout.cpp" line="-16"/>
+        <location filename="../src/core/RBlock.cpp" line="-6"/>
+        <location filename="../src/core/RLayer.cpp" line="-8"/>
+        <location filename="../src/core/RLayout.cpp" line="-24"/>
         <source>Name</source>
         <translation>Nome</translation>
     </message>
     <message>
         <location line="+1"/>
-        <location filename="../src/core/RLayer.cpp" line="+1"/>
         <source>Hidden</source>
         <translation>Oculto</translation>
     </message>
     <message>
         <location filename="../src/core/RLayer.cpp" line="+1"/>
+        <source>Off</source>
+        <translation>Inativo</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Frozen</source>
+        <translation>Congelado</translation>
+    </message>
+    <message>
+        <location line="+1"/>
         <source>Locked</source>
         <translation>Bloqueado</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Collapsed</source>
+        <translation>Guardada</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Plottable</source>
+        <translation>Plotável</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Snappable</source>
+        <translation>Ajustável</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Off is Freeze</source>
+        <translation>Inativo está congelado</translation>
+    </message>
     <message>
         <location filename="../src/core/RLayout.cpp" line="+1"/>
         <source>Tab Order</source>
@@ -779,11 +834,25 @@ Abre diálogo de cores</translatorcomment>
         <source>Max Extents</source>
         <translation>Extensões máximos</translation>
     </message>
+    <message>
+        <source>Plot Margins</source>
+        <translation type="vanished">Margens de trama</translation>
+    </message>
+    <message>
+        <location filename="../src/core/RBlockReferenceData.cpp" line="+627"/>
+        <source>Circular (recursive) block referencing detected:</source>
+        <translation>Foi detectada uma referência de bloco circular (recursiva):</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Block name:</source>
+        <translation>Nome do bloco:</translation>
+    </message>
 </context>
 <context>
     <name>RGuiAction</name>
     <message>
-        <location filename="../src/core/RGuiAction.cpp" line="+182"/>
+        <location filename="../src/core/RGuiAction.cpp" line="+184"/>
         <source>Requires selection</source>
         <translatorcomment>--google--</translatorcomment>
         <translation>Requer uma seleção</translation>
@@ -1002,7 +1071,7 @@ Borda (grande)</translatorcomment>
 <context>
     <name>RLinetypePattern</name>
     <message>
-        <location filename="../src/core/RLinetypePattern.cpp" line="+845"/>
+        <location filename="../src/core/RLinetypePattern.cpp" line="+856"/>
         <source>By Layer</source>
         <translation>Pela Camada</translation>
     </message>
