@@ -4,7 +4,7 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/core/RUnit.cpp" line="+268"/>
+        <location filename="../src/core/RUnit.cpp" line="+273"/>
         <source>None</source>
         <translation>Нет</translation>
     </message>
@@ -246,24 +246,29 @@
         <location line="+1"/>
         <location line="+1"/>
         <location line="+1"/>
-        <location filename="../src/core/RViewportEntity.cpp" line="+71"/>
+        <location filename="../src/core/RViewportEntity.cpp" line="+73"/>
         <location line="+1"/>
         <location line="+1"/>
         <source>Position</source>
         <translation>Положение</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlock.cpp" line="+62"/>
+        <location filename="../src/core/RBlock.cpp" line="+65"/>
+        <source>Pixel Unit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
         <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
         <location line="+3"/>
-        <location filename="../src/core/RLayout.cpp" line="+77"/>
+        <location filename="../src/core/RLayout.cpp" line="+82"/>
         <location line="+3"/>
         <location line="+3"/>
         <location line="+3"/>
         <location line="+3"/>
         <location filename="../src/core/RTextBasedEntity.cpp" line="+72"/>
         <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
-        <location line="+6"/>
+        <location line="+8"/>
         <location line="+2"/>
         <source>X</source>
         <translation>X</translation>
@@ -285,8 +290,8 @@
         <location line="+3"/>
         <location line="+3"/>
         <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
-        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
-        <location line="+6"/>
+        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
+        <location line="+8"/>
         <location line="+2"/>
         <source>Y</source>
         <translation>Y</translation>
@@ -301,21 +306,21 @@
         <location line="+3"/>
         <location line="+3"/>
         <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
-        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
-        <location line="+8"/>
+        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
+        <location line="+10"/>
         <source>Z</source>
         <translation>Z</translation>
     </message>
     <message>
         <location line="+1"/>
         <source>Layout</source>
-        <translation type="unfinished"></translation>
+        <translation>Расположение</translation>
     </message>
     <message>
         <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
         <location line="+1"/>
         <location line="+1"/>
-        <location filename="../src/core/RViewportEntity.cpp" line="-5"/>
+        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
         <source>Scale</source>
         <translation>Масшабировать</translation>
     </message>
@@ -345,8 +350,13 @@
         <translation>Расстояние между строками</translation>
     </message>
     <message>
-        <location filename="../src/core/REntity.cpp" line="+86"/>
-        <location filename="../src/core/RObject.cpp" line="+63"/>
+        <location line="+3"/>
+        <source>Attributes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/core/REntity.cpp" line="+87"/>
+        <location filename="../src/core/RObject.cpp" line="+66"/>
         <source>Type</source>
         <translation>Тип</translation>
     </message>
@@ -362,7 +372,7 @@
     </message>
     <message>
         <location line="+1"/>
-        <location filename="../src/core/RLayer.cpp" line="+80"/>
+        <location filename="../src/core/RLayer.cpp" line="+99"/>
         <source>Linetype</source>
         <translation>Тип линии</translation>
     </message>
@@ -403,21 +413,25 @@
     </message>
     <message>
         <location line="-3"/>
+        <location filename="../src/core/RLayout.cpp" line="+3"/>
         <source>Left</source>
         <translation>Левая</translation>
     </message>
     <message>
         <location line="+1"/>
+        <location filename="../src/core/RLayout.cpp" line="+1"/>
         <source>Bottom</source>
         <translation>Низ</translation>
     </message>
     <message>
         <location line="+1"/>
+        <location filename="../src/core/RLayout.cpp" line="+1"/>
         <source>Right</source>
         <translation>Правая</translation>
     </message>
     <message>
         <location line="+1"/>
+        <location filename="../src/core/RLayout.cpp" line="+1"/>
         <source>Top</source>
         <translation>Верх</translation>
     </message>
@@ -439,6 +453,7 @@
     </message>
     <message>
         <location filename="../src/core/REntity.cpp" line="+2"/>
+        <location filename="../src/core/RLayout.cpp" line="+1"/>
         <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
         <source>Width</source>
         <translation>ширину</translation>
@@ -451,6 +466,7 @@
     </message>
     <message>
         <location line="+0"/>
+        <location filename="../src/core/RLayout.cpp" line="+1"/>
         <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
         <source>Height</source>
         <translation>высоту</translation>
@@ -530,6 +546,16 @@
     </message>
     <message>
         <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
+        <source>Rotation</source>
+        <translation>вращение</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>On</source>
+        <translation>вкл</translation>
+    </message>
+    <message>
+        <location line="+1"/>
         <location line="+1"/>
         <source>View Center</source>
         <translation>Посмотреть Центр</translation>
@@ -544,30 +570,59 @@
     <message>
         <location line="+2"/>
         <source>Overall</source>
-        <translation type="unfinished"></translation>
+        <translation>Общий</translation>
     </message>
     <message>
-        <location filename="../src/core/RBlock.cpp" line="-5"/>
-        <location filename="../src/core/RLayer.cpp" line="-3"/>
-        <location filename="../src/core/RLayout.cpp" line="-16"/>
+        <location filename="../src/core/RBlock.cpp" line="-6"/>
+        <location filename="../src/core/RLayer.cpp" line="-8"/>
+        <location filename="../src/core/RLayout.cpp" line="-24"/>
         <source>Name</source>
         <translation>Имя</translation>
     </message>
     <message>
         <location line="+1"/>
-        <location filename="../src/core/RLayer.cpp" line="+1"/>
         <source>Hidden</source>
         <translation>Скрытый</translation>
     </message>
     <message>
         <location filename="../src/core/RLayer.cpp" line="+1"/>
+        <source>Off</source>
+        <translation>выкл</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Frozen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
         <source>Locked</source>
         <translation>Запертый</translation>
     </message>
+    <message>
+        <location line="+1"/>
+        <source>Collapsed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Plottable</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Snappable</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>Off is Freeze</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../src/core/RLayout.cpp" line="+1"/>
         <source>Tab Order</source>
-        <translation type="unfinished"></translation>
+        <translation>Порядок перехода</translation>
     </message>
     <message>
         <location line="+1"/>
@@ -604,11 +659,21 @@
         <source>Max Extents</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../src/core/RBlockReferenceData.cpp" line="+627"/>
+        <source>Circular (recursive) block referencing detected:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Block name:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RGuiAction</name>
     <message>
-        <location filename="../src/core/RGuiAction.cpp" line="+182"/>
+        <location filename="../src/core/RGuiAction.cpp" line="+184"/>
         <source>Requires selection</source>
         <translation>Выделение требований</translation>
     </message>
@@ -666,7 +731,7 @@
 <context>
     <name>RLinetypePattern</name>
     <message>
-        <location filename="../src/core/RLinetypePattern.cpp" line="+845"/>
+        <location filename="../src/core/RLinetypePattern.cpp" line="+856"/>
         <source>By Layer</source>
         <translation> По слою</translation>
     </message>
